@@ -15,6 +15,7 @@
 #include "../../../libgammu/service/gsmnet.h"
 #include "../../gammu.h"
 #include "../../../helper/string.h"
+#include "../../../helper/cmdline.h"
 
 extern GSM_Reply_Function UserReplyFunctions3[];
 
@@ -53,8 +54,8 @@ void CheckDCT3(void)
 	switch (error) {
 		case ERR_OTHERCONNECTIONREQUIRED:
 			printf("Can't do it with current phone protocol\n");
-			GSM_TerminateConnection(gsm);
-			Terminate(3);
+			Print_Error(error);
+			break;
 		case ERR_NONE:
 			break;
 		default:
@@ -71,7 +72,9 @@ static gboolean answer_yes3(const char *text)
 	while (1) {
 		printf("%s (yes/no) ? ",text);
 		len=GetLine(stdin, ans, 99);
-		if (len==-1) Terminate(3);
+		if (len==-1) {
+			Terminate(2);
+		}
 		if (strcasecmp(ans, "yes") == 0) return TRUE;
 		if (strcasecmp(ans, "no" ) == 0) return FALSE;
 	}
@@ -310,13 +313,13 @@ void DCT3DisplayTest(int argc, char *argv[])
 
 	CheckDCT3();
 
-	if (atoi(argv[2]) != 1 && atoi(argv[2]) != 2) {
+	if (GetInt(argv[2]) != 1 && GetInt(argv[2]) != 2) {
 		printf("Give 1 or 2 as test number\n");
 	}
 
 	gsm->User.UserReplyFunctions=UserReplyFunctions3;
 
-	req[4] = atoi(argv[2]);
+	req[4] = GetInt(argv[2]);
 	gsm->Protocol.Functions->WriteMessage(gsm, req, 5, 0x40);
 
 	printf("Press any key to continue...\n");
@@ -339,12 +342,12 @@ void DCT3netmonitor(int argc, char *argv[])
 
         CheckDCT3();
 
-	error=DCT3_Netmonitor(gsm, atoi(argv[2]), value);
+	error=DCT3_Netmonitor(gsm, GetInt(argv[2]), value);
 	Print_Error(error);
 
 	printf("%s\n",value);
 #ifdef GSM_ENABLE_BEEP
-	if (atoi(argv[2]) == 243) GSM_PhoneBeep();
+	if (GetInt(argv[2]) == 243) GSM_PhoneBeep();
 #endif
 	GSM_Terminate();
 }
