@@ -158,7 +158,8 @@ static void mdircv_data(unsigned char type, unsigned char *buffer, size_t length
 static GSM_Error DCT3_ReplyDebugTrace(GSM_Protocol_Message msg, GSM_StateMachine *sm)
 {
 	size_t 			x;
-	int 			id,timestamp,number,length;
+	int 			id,timestamp,number;
+	size_t			length;
 	struct wmx_tracetype 	*wmx_minor;
 	const char 			*desc;
 
@@ -259,18 +260,18 @@ static GSM_Error DCT3_ReplyDebugTrace(GSM_Protocol_Message msg, GSM_StateMachine
  		}
  		break;
  	case 0x22: /* 0x27 SIM answer to command (error/ok/etc..) */
- 		if(msg.Length<10) {
+ 		if(msg.Length < 10 || msg.Length < length + 8) {
  		    	// Unknown response
- 		    	for(x=0;x<msg.Length-10;x++) printf("%02x ", msg.Buffer[x]&0xFF);
+ 		    	for(x=0;x<msg.Length;x++) printf("%02x ", msg.Buffer[x]&0xFF);
 			printf(" (Unknown 0x27 packet ? ? )\n");
  		} else {
  		    	simAnswer_Process((unsigned char)(id&0xFF), (unsigned char*)&msg.Buffer[8], length);
  		}
  		break;
  	case 0x23:  /* 0x28 SIM response data to commands */
- 		if(msg.Length<10) {
+ 		if(msg.Length < 10 || msg.Length < length + 8) {
  		    	// Unknown response
- 		    	for(x=0;x<msg.Length-10;x++) printf("%02x ", msg.Buffer[x]&0xFF);
+ 		    	for(x=0;x<msg.Length;x++) printf("%02x ", msg.Buffer[x]&0xFF);
  		    	printf(" (Unknown 0x28 packet)\n");
  		} else {
  		    	simResponse_Process((unsigned char)(id&0xFF), (unsigned char*)&msg.Buffer[8], length);
@@ -414,10 +415,10 @@ void DCT3SetDebug(int argc, char *argv[])
 	//ENABLE_BIT(0x22, 1);  /* SIM commands (literal) */
 	//ENABLE_BIT(0x3B, 1);	/* PHCTRL state */
 
-	GSM_Init(true);
+	GSM_Init(TRUE);
 
 	/* We Need DCT3 */
-	if (CheckDCT3Only()!=ERR_NONE) return;
+	CheckDCT3();
 
 	error=DCT3_EnableSecurity (gsm, 0x01);
 	Print_Error(error);
@@ -455,7 +456,7 @@ void DCT3SetDebug(int argc, char *argv[])
 
 	/* todo: wait and dump for some time */
 	while (!gshutdown) {
-		GSM_ReadDevice(gsm,true);
+		GSM_ReadDevice(gsm,TRUE);
 		usleep(10000);
 	}
 	signal(SIGINT, SIG_DFL);
