@@ -1,7 +1,7 @@
 #define _GNU_SOURCE		/* For strcasestr */
 #include <string.h>
 
-#include "../common/misc/locales.h"
+#include "../helper/locales.h"
 
 #include <gammu.h>
 #include <stdlib.h>
@@ -23,7 +23,10 @@
 #include "memory.h"
 #include "message.h"
 #include "common.h"
-#include "formats.h"
+
+#include "../helper/formats.h"
+#include "../helper/printing.h"
+#include "../helper/string.h"
 
 /**
  * Displays status of filesystem (if available).
@@ -42,13 +45,15 @@ GSM_Error PrintFileSystemStatus(void)
 
 	printf("\n");
 
-	printf(_("Phone memory: %i bytes (free %i bytes, used %i bytes)"),
+	printf(LISTFORMAT, _("Phone memory"));
+	printf(_("%i bytes (free %i bytes, used %i bytes)"),
 	       Status.Free + Status.Used, Status.Free, Status.Used);
 	printf("\n");
 
 	if (Status.UsedImages != 0 || Status.UsedSounds != 0
 	    || Status.UsedThemes != 0) {
-		printf(_("Used by: Images: %i, Sounds: %i, Themes: %i"),
+		printf(LISTFORMAT, _("Usage details"));
+		printf(_("images: %i, sounds: %i, themes: %i"),
 		       Status.UsedImages, Status.UsedSounds, Status.UsedThemes);
 		printf("\n");
 	}
@@ -58,9 +63,11 @@ GSM_Error PrintFileSystemStatus(void)
 
 void GetFileSystemStatus(int argc UNUSED, char *argv[]UNUSED)
 {
-	GSM_Init(true);
+	GSM_Error error;
+	GSM_Init(TRUE);
 
-	PrintFileSystemStatus();
+	error = PrintFileSystemStatus();
+	Print_Error(error);
 
 	GSM_Terminate();
 }
@@ -68,13 +75,13 @@ void GetFileSystemStatus(int argc UNUSED, char *argv[]UNUSED)
 void GetFileSystem(int argc, char *argv[])
 {
 	GSM_Error error;
-	bool Start = true, MemoryCard = false;
+	gboolean Start = TRUE, MemoryCard = FALSE;
 	GSM_File Files;
 	int j;
 	long usedphone = 0, usedcard = 0;
 	char FolderName[256], IDUTF[200];
 
-	GSM_Init(true);
+	GSM_Init(TRUE);
 
 	while (1) {
 		error = GSM_GetNextFileFolder(gsm, &Files, Start);
@@ -88,7 +95,7 @@ void GetFileSystem(int argc, char *argv[])
 			    (GSM_GetModelInfo(gsm), F_FILES2)) {
 				if (DecodeUnicodeString(Files.ID_FullName)[0] ==
 				    'a') {
-					MemoryCard = true;
+					MemoryCard = TRUE;
 					usedcard += Files.Used;
 				} else {
 					usedphone += Files.Used;
@@ -109,25 +116,25 @@ void GetFileSystem(int argc, char *argv[])
 			}
 			if (Files.Protected) {
 				/* l10n: One char to indicate protected file */
-				printf(_("P"));
+				printf("%s", _("P"));
 			} else {
 				printf(" ");
 			}
 			if (Files.ReadOnly) {
 				/* l10n: One char to indicate read only file */
-				printf(_("R"));
+				printf("%s", _("R"));
 			} else {
 				printf(" ");
 			}
 			if (Files.Hidden) {
 				/* l10n: One char to indicate hidden file */
-				printf(_("H"));
+				printf("%s", _("H"));
 			} else {
 				printf(" ");
 			}
 			if (Files.System) {
 				/* l10n: One char to indicate system file */
-				printf(_("S"));
+				printf("%s", _("S"));
 			} else {
 				printf(" ");
 			}
@@ -139,7 +146,7 @@ void GetFileSystem(int argc, char *argv[])
 							printf(" %30s",
 							       OSDateTime(Files.
 									  Modified,
-									  false));
+									  FALSE));
 						} else
 							printf(" %30c", 0x20);
 						printf(" %9li", (long)Files.Used);
@@ -148,9 +155,9 @@ void GetFileSystem(int argc, char *argv[])
 						printf("|-- ");
 				} else {
 					if (error == ERR_FOLDERPART) {
-						printf(_("Part of folder "));
+						printf("%s ", _("Part of folder"));
 					} else {
-						printf(_("Folder "));
+						printf("%s ", _("Folder"));
 					}
 				}
 			} else {
@@ -161,9 +168,9 @@ void GetFileSystem(int argc, char *argv[])
 				}
 				if (Files.Folder) {
 					if (error == ERR_FOLDERPART) {
-						printf(_("Part of folder "));
+						printf("%s ", _("Part of folder"));
 					} else {
-						printf(_("Folder "));
+						printf("%s ", _("Folder"));
 					}
 				}
 			}
@@ -174,22 +181,22 @@ void GetFileSystem(int argc, char *argv[])
 			EncodeUTF8QuotedPrintable(IDUTF, Files.ID_FullName);
 			printf("%s;", IDUTF);
 			if (!Files.Folder) {
-				printf(_("File;"));
+				printf("%s", _("File;"));
 				printf("\"%s\";", FolderName);
 				printf("\"%s\";",
 				       DecodeUnicodeConsole(Files.Name));
 				if (!Files.ModifiedEmpty) {
 					printf("\"%s\";",
 					       OSDateTime(Files.Modified,
-							  false));
+							  FALSE));
 				} else
 					printf("\"%c\";", 0x20);
-				printf(SIZE_T_FORMAT ";", Files.Used);
+				printf("%ld;", (long)Files.Used);
 			} else {
 				if (error == ERR_FOLDERPART) {
-					printf(_("Part of folder;"));
+					printf("%s;", _("Part of folder"));
 				} else {
-					printf(_("Folder;"));
+					printf("%s;", _("Folder"));
 				}
 				printf("\"%s\";",
 				       DecodeUnicodeConsole(Files.Name));
@@ -198,16 +205,16 @@ void GetFileSystem(int argc, char *argv[])
 			}
 
 			if (Files.Protected)
-				printf(_("P"));
+				printf("%s", _("P"));
 			if (Files.ReadOnly)
-				printf(_("R"));
+				printf("%s", _("R"));
 			if (Files.Hidden)
-				printf(_("H"));
+				printf("%s", _("H"));
 			if (Files.System)
-				printf(_("S"));
+				printf("%s", _("S"));
 			printf("\n");
 		}
-		Start = false;
+		Start = FALSE;
 	}
 
 	error = PrintFileSystemStatus();
@@ -229,28 +236,28 @@ void SetFileAttrib(int argc, char *argv[])
 	GSM_Error error;
 	int i;
 
-	Files.ReadOnly = false;
-	Files.Protected = false;
-	Files.System = false;
-	Files.Hidden = false;
+	Files.ReadOnly = FALSE;
+	Files.Protected = FALSE;
+	Files.System = FALSE;
+	Files.Hidden = FALSE;
 
 	DecodeUTF8QuotedPrintable(Files.ID_FullName, argv[2], strlen(argv[2]));
 
 	for (i = 3; i < argc; i++) {
 		if (strcasecmp(argv[i], "-readonly") == 0) {
-			Files.ReadOnly = true;
+			Files.ReadOnly = TRUE;
 		} else if (strcasecmp(argv[i], "-protected") == 0) {
-			Files.Protected = true;
+			Files.Protected = TRUE;
 		} else if (strcasecmp(argv[i], "-system") == 0) {
-			Files.System = true;
+			Files.System = TRUE;
 		} else if (strcasecmp(argv[i], "-hidden") == 0) {
-			Files.Hidden = true;
+			Files.Hidden = TRUE;
 		} else {
 			fprintf(stderr, _("Unknown attribute (%s)\n"), argv[i]);
 		}
 	}
 
-	GSM_Init(true);
+	GSM_Init(TRUE);
 
 	error = GSM_SetFileAttributes(gsm, &Files);
 	Print_Error(error);
@@ -263,7 +270,7 @@ void GetRootFolders(int argc UNUSED, char *argv[]UNUSED)
 	GSM_File File;
 	char IDUTF[200];
 
-	GSM_Init(true);
+	GSM_Init(TRUE);
 
 	File.ID_FullName[0] = 0;
 	File.ID_FullName[1] = 0;
@@ -282,11 +289,11 @@ void GetRootFolders(int argc UNUSED, char *argv[]UNUSED)
 void GetFolderListing(int argc UNUSED, char *argv[])
 {
 	GSM_Error error;
-	bool Start = true;
+	gboolean Start = TRUE;
 	GSM_File Files;
 	char IDUTF[200];
 
-	GSM_Init(true);
+	GSM_Init(TRUE);
 
 	DecodeUTF8QuotedPrintable(Files.ID_FullName, argv[2], strlen(argv[2]));
 
@@ -305,40 +312,40 @@ void GetFolderListing(int argc UNUSED, char *argv[])
 		EncodeUTF8QuotedPrintable(IDUTF, Files.ID_FullName);
 		printf("%s;", IDUTF);
 		if (!Files.Folder) {
-			printf(_("File;"));
+			printf("%s", _("File;"));
 			printf("\"%s\";", DecodeUnicodeConsole(Files.Name));
 			if (!Files.ModifiedEmpty) {
 				printf("\"%s\";",
-				       OSDateTime(Files.Modified, false));
+				       OSDateTime(Files.Modified, FALSE));
 			} else
 				printf("\"%c\";", 0x20);
-			printf(SIZE_T_FORMAT ";", Files.Used);
+			printf("%ld;", (long)Files.Used);
 		} else {
-			printf(_("Folder"));
+			printf("%s", _("Folder"));
 			printf(";\"%s\";", DecodeUnicodeConsole(Files.Name));
 		}
 
 		if (Files.Protected)
-			printf(_("P"));
+			printf("%s", _("P"));
 		if (Files.ReadOnly)
-			printf(_("R"));
+			printf("%s", _("R"));
 		if (Files.Hidden)
-			printf(_("H"));
+			printf("%s", _("H"));
 		if (Files.System)
-			printf(_("S"));
+			printf("%s", _("S"));
 		printf("\n");
 
-		Start = false;
+		Start = FALSE;
 	}
 
 	GSM_Terminate();
 }
 
-void GetOneFile(GSM_File * File, bool newtime, int i)
+void GetOneFile(GSM_File * File, gboolean newtime, int i)
 {
 	GSM_Error error;
 	FILE *file;
-	bool start;
+	gboolean start;
 	unsigned char buffer[5000];
 	struct utimbuf filedate;
 	int Handle, Size, p, q, j, old1;
@@ -350,7 +357,7 @@ void GetOneFile(GSM_File * File, bool newtime, int i)
 		File->Buffer = NULL;
 	}
 	File->Used = 0;
-	start = true;
+	start = TRUE;
 
 	t_time1 = time(NULL);
 	old1 = 65536;
@@ -363,20 +370,20 @@ void GetOneFile(GSM_File * File, bool newtime, int i)
 			if (start) {
 				printf(_("Getting \"%s\"\n"),
 				       DecodeUnicodeConsole(File->Name));
-				start = false;
+				start = FALSE;
 			}
 			if (File->Folder) {
 				free(File->Buffer);
 				GSM_Terminate();
 				printf("%s\n",
-				       _
-				       ("it's folder. Please give only file names"));
-				exit(-1);
+				       _ ("Is a folder. Please give only file names."));
+				Terminate(2);
 			}
 			if (Size == 0) {
-				printf("*");
+				fprintf(stderr, "*");
 			} else {
-				fprintf(stderr, _("%c  %i percent"), 13,
+				fprintf(stderr, "\r");
+				fprintf(stderr, _("%i percent"),
 					(int)(File->Used * 100 / Size));
 				if (File->Used * 100 / Size >= 2) {
 					t_time2 = time(NULL);
@@ -400,14 +407,14 @@ void GetOneFile(GSM_File * File, bool newtime, int i)
 				break;
 			if (error == ERR_WRONGCRC) {
 				printf_warn("%s\n",
-					    _
-					    ("File checksum calculated by phone doesn't match with value calculated by Gammu. File damaged or error in Gammu"));
+				    _("File checksum calculated by phone doesn't match with value calculated by Gammu. File is damaged or there is a error in Gammu."));
 				break;
 			}
 		}
 		Print_Error(error);
 	}
-	printf("\n");
+	fprintf(stderr, "\n");
+	fflush(stderr);
 	if (error == ERR_NONE || error == ERR_EMPTY || error == ERR_WRONGCRC) {
 		if (File->Used != 0) {
 			sprintf(buffer, "%s", DecodeUnicodeConsole(File->Name));
@@ -434,15 +441,17 @@ void GetOneFile(GSM_File * File, bool newtime, int i)
 				Print_Error(ERR_CANTOPENFILE);
 			printf(_("  Saving to %s\n"), buffer);
 			if (fwrite(File->Buffer, 1, File->Used, file) != File->Used) {
-				printf_err(_("Error while writing file!\n"));
+				printf_err("%s", _("Error while writing file!\n"));
 			}
+			free(File->Buffer);
+			File->Buffer = NULL;
 			fclose(file);
 			if (!newtime && !File->ModifiedEmpty) {
 				/* access time */
 				filedate.actime = Fill_Time_T(File->Modified);
 				/* modification time */
 				filedate.modtime = Fill_Time_T(File->Modified);
-				dbgprintf("Setting date of %s\n", buffer);
+				smprintf(gsm, "Setting date of %s\n", buffer);
 				utime(buffer, &filedate);
 			}
 		}
@@ -453,45 +462,44 @@ void GetFiles(int argc, char *argv[])
 {
 	GSM_File File;
 	int i;
-	bool newtime = false;
+	gboolean newtime = FALSE;
 
 	File.Buffer = NULL;
 
-	GSM_Init(true);
+	GSM_Init(TRUE);
 
 	for (i = 2; i < argc; i++) {
 		if (strcasecmp(argv[i], "-newtime") == 0) {
-			newtime = true;
+			newtime = TRUE;
 			continue;
 		}
 
 		DecodeUTF8QuotedPrintable(File.ID_FullName, argv[i],
 					  strlen(argv[i]));
-		dbgprintf("grabbing '%s' '%s'\n",
+		smprintf(gsm, "grabbing '%s' '%s'\n",
 			  DecodeUnicodeString(File.ID_FullName), argv[i]);
 		GetOneFile(&File, newtime, i);
 	}
 
-	free(File.Buffer);
 	GSM_Terminate();
 }
 
 void GetFileFolder(int argc, char *argv[])
 {
 	GSM_Error error;
-	bool Start = true;
+	gboolean Start = TRUE;
 	GSM_File File;
 	int level = 0, allnum = 0, num = 0, filelevel = 0, i = 0;
-	bool newtime = false, found;
+	gboolean newtime = FALSE, found;
 	unsigned char IDUTF[200];
 
 	File.Buffer = NULL;
 
-	GSM_Init(true);
+	GSM_Init(TRUE);
 
 	for (i = 2; i < argc; i++) {
 		if (strcasecmp(argv[i], "-newtime") == 0) {
-			newtime = true;
+			newtime = TRUE;
 			continue;
 		}
 		allnum++;
@@ -505,23 +513,23 @@ void GetFileFolder(int argc, char *argv[])
 
 		if (level == 0) {
 			/* We search for file or folder */
-			found = false;
+			found = FALSE;
 			for (i = 2; i < argc; i++) {
 				if (strcasecmp(argv[i], "-newtime") == 0) {
 					continue;
 				}
-				dbgprintf("comparing %s %s\n",
+				smprintf(gsm, "comparing %s %s\n",
 					  DecodeUnicodeString(File.ID_FullName),
 					  argv[i]);
 				DecodeUTF8QuotedPrintable(IDUTF, argv[i],
 							  strlen(argv[i]));
 				if (mywstrncasecmp(File.ID_FullName, IDUTF, 0)) {
-					dbgprintf("found folder");
-					found = true;
+					smprintf(gsm, "found folder");
+					found = TRUE;
 					if (File.Folder) {
 						level = 1;
 						filelevel = File.Level + 1;
-						Start = false;
+						Start = FALSE;
 					} else {
 						level = 2;
 					}
@@ -533,7 +541,7 @@ void GetFileFolder(int argc, char *argv[])
 		}
 		if (level == 1) {
 			/* We have folder */
-			dbgprintf("%i %i\n", File.Level, filelevel);
+			smprintf(gsm, "%i %i\n", File.Level, filelevel);
 			if (File.Level != filelevel) {
 				level = 0;
 				num++;
@@ -550,14 +558,14 @@ void GetFileFolder(int argc, char *argv[])
 			num++;
 		}
 
-		Start = false;
+		Start = FALSE;
 	}
 
 	free(File.Buffer);
 	GSM_Terminate();
 }
 
-void AddOneFile(GSM_File * File, const char *text, const bool send)
+void AddOneFile(GSM_File * File, const char *text, const gboolean send)
 {
 	GSM_Error error;
 	int Pos, Handle, i, j, old1;
@@ -569,7 +577,7 @@ void AddOneFile(GSM_File * File, const char *text, const bool send)
 	t_time1 = Fill_Time_T(dt);
 	old1 = 65536;
 
-	dbgprintf("Adding file to filesystem now\n");
+	smprintf(gsm, "Adding file to filesystem now\n");
 	error = ERR_NONE;
 	Pos = 0;
 	while (error == ERR_NONE) {
@@ -582,8 +590,8 @@ void AddOneFile(GSM_File * File, const char *text, const bool send)
 			Print_Error(error);
 		if (File->Used != 0) {
 			fprintf(stderr, "\r");
-			fprintf(stderr, "%s", text);
-			fprintf(stderr, _("%3i percent"),
+			fprintf(stderr, "%s ", text);
+			fprintf(stderr, _("%i percent"),
 				(int)(Pos * 100 / File->Used));
 			if (Pos * 100 / File->Used >= 2) {
 				GSM_GetCurrentDateTime(&dt);
@@ -606,8 +614,7 @@ void AddOneFile(GSM_File * File, const char *text, const bool send)
 	fprintf(stderr, "\n");
 	if (error == ERR_WRONGCRC) {
 		printf_warn("%s\n",
-			    _
-			    ("File checksum calculated by phone doesn't match with value calculated by Gammu. File damaged or error in Gammu"));
+		    _("File checksum calculated by phone doesn't match with value calculated by Gammu. File is damaged or there is a error in Gammu."));
 	}
 }
 
@@ -617,11 +624,11 @@ void AddSendFile(int argc, char *argv[])
 	GSM_File File;
 	int i, nextlong;
 	char IDUTF[200];
-	bool sendfile = false;
+	gboolean sendfile = FALSE;
 	int optint = 2;
 
 	if (strcasestr(argv[1], "sendfile") != NULL) {
-		sendfile = true;
+		sendfile = TRUE;
 	}
 
 	File.Buffer = NULL;
@@ -645,10 +652,10 @@ void AddSendFile(int argc, char *argv[])
 
 	GSM_IdentifyFileFormat(&File);
 
-	File.Protected = false;
-	File.ReadOnly = false;
-	File.Hidden = false;
-	File.System = false;
+	File.Protected = FALSE;
+	File.ReadOnly = FALSE;
+	File.Hidden = FALSE;
+	File.System = FALSE;
 
 	if (argc > optint) {
 		nextlong = 0;
@@ -661,30 +668,30 @@ void AddSendFile(int argc, char *argv[])
 					}
 					if (strcasecmp(argv[i], "-protected") ==
 					    0) {
-						File.Protected = true;
+						File.Protected = TRUE;
 						continue;
 					}
 					if (strcasecmp(argv[i], "-readonly") ==
 					    0) {
-						File.ReadOnly = true;
+						File.ReadOnly = TRUE;
 						continue;
 					}
 					if (strcasecmp(argv[i], "-hidden") == 0) {
-						File.Hidden = true;
+						File.Hidden = TRUE;
 						continue;
 					}
 					if (strcasecmp(argv[i], "-system") == 0) {
-						File.System = true;
+						File.System = TRUE;
 						continue;
 					}
 					if (strcasecmp(argv[i], "-newtime") ==
 					    0) {
-						File.ModifiedEmpty = true;
+						File.ModifiedEmpty = TRUE;
 						continue;
 					}
 					printf(_("Parameter \"%s\" unknown\n"),
 					       argv[i]);
-					exit(-1);
+					Terminate(2);
 				case 1:
 					if (strcasecmp(argv[i], "JAR") == 0) {
 						File.Type = GSM_File_Java_JAR;
@@ -719,7 +726,7 @@ void AddSendFile(int argc, char *argv[])
 						printf(_
 						       ("What file type (\"%s\") ?\n"),
 						       argv[i]);
-						exit(-1);
+						Terminate(2);
 					}
 					nextlong = 0;
 					break;
@@ -727,13 +734,13 @@ void AddSendFile(int argc, char *argv[])
 		}
 		if (nextlong != 0) {
 			printf_err("%s\n", _("Parameter missing!"));
-			exit(-1);
+			Terminate(2);
 		}
 	}
 
-	GSM_Init(true);
+	GSM_Init(TRUE);
 
-	AddOneFile(&File, "Writing: ", sendfile);
+	AddOneFile(&File, _("Writing:"), sendfile);
 	EncodeUTF8QuotedPrintable(IDUTF, File.ID_FullName);
 	printf(_("ID of new file is \"%s\"\n"), IDUTF);
 
@@ -749,9 +756,9 @@ void AddFolder(int argc UNUSED, char *argv[])
 
 	DecodeUTF8QuotedPrintable(File.ID_FullName, argv[2], strlen(argv[2]));
 	EncodeUnicode(File.Name, argv[3], strlen(argv[3]));
-	File.ReadOnly = false;
+	File.ReadOnly = FALSE;
 
-	GSM_Init(true);
+	GSM_Init(TRUE);
 
 	error = GSM_AddFolder(gsm, &File);
 	Print_Error(error);
@@ -766,7 +773,7 @@ void DeleteFolder(int argc UNUSED, char *argv[]UNUSED)
 	GSM_Error error;
 	unsigned char buffer[500];
 
-	GSM_Init(true);
+	GSM_Init(TRUE);
 
 	DecodeUTF8QuotedPrintable(buffer, argv[2], strlen(argv[2]));
 
@@ -782,7 +789,7 @@ void DeleteFiles(int argc, char *argv[])
 	int i;
 	unsigned char buffer[500];
 
-	GSM_Init(true);
+	GSM_Init(TRUE);
 
 	for (i = 2; i < argc; i++) {
 		DecodeUTF8QuotedPrintable(buffer, argv[i], strlen(argv[i]));
