@@ -11,6 +11,7 @@
 #ifdef HAVE_UNISTD_H
 #include <unistd.h>
 #endif
+#include <locale.h>
 
 #include "common.h"
 #include "misc.h"
@@ -58,6 +59,33 @@ void PrintNetworkInfo(GSM_NetworkInfo NetInfo)
 				DecodeUnicodeConsole(NetInfo.NetworkName));
 		}
 	}
+	printf(LISTFORMAT, _("Packet network state"));
+	switch (NetInfo.PacketState) {
+		case GSM_HomeNetwork		: printf("%s\n", _("home network")); 		 	break;
+		case GSM_RoamingNetwork		: printf("%s\n", _("roaming network")); 	 	break;
+		case GSM_RequestingNetwork	: printf("%s\n", _("requesting network")); 	 	break;
+		case GSM_NoNetwork		: printf("%s\n", _("not logged into network")); 	break;
+		case GSM_RegistrationDenied	: printf("%s\n", _("registration to network denied"));	break;
+		case GSM_NetworkStatusUnknown	: printf("%s\n", _("unknown"));			break;
+#ifndef CHECK_CASES
+		default				: printf("%s\n", _("unknown"));
+#endif
+	}
+	if (NetInfo.PacketState == GSM_HomeNetwork || NetInfo.PacketState == GSM_RoamingNetwork) {
+		printf(LISTFORMAT, _("Packet network"));
+		printf("%s (%s",
+			NetInfo.NetworkCode,
+			DecodeUnicodeConsole(GSM_GetNetworkName(NetInfo.NetworkCode)));
+		printf(", %s)",
+			DecodeUnicodeConsole(GSM_GetCountryName(NetInfo.NetworkCode)));
+		printf(", LAC %s, CID %s\n",
+			NetInfo.PacketLAC, NetInfo.PacketCID);
+		if (NetInfo.NetworkName[0] != 0x00 || NetInfo.NetworkName[1] != 0x00) {
+			printf(LISTFORMAT "\"%s\"\n",
+				_("Name in phone"),
+				DecodeUnicodeConsole(NetInfo.NetworkName));
+		}
+	}
 	if (NetInfo.GPRS != 0) {
 		printf(LISTFORMAT, _("GPRS"));
 		switch (NetInfo.GPRS) {
@@ -113,80 +141,6 @@ void PlayRingtone(int argc UNUSED, char *argv[])
 	GSM_Terminate();
 }
 
-/**
- * Checks for firmware version available in Gammu database.
- */
-void CheckFirmware(int argc UNUSED, char *argv[]UNUSED)
-{
-	GSM_File PhoneDB;
-	char model[GSM_MAX_MODEL_LENGTH];
-	char current_version[GSM_MAX_VERSION_LENGTH];
-	char url[70 + GSM_MAX_MODEL_LENGTH];
-	char latest_version[GSM_MAX_VERSION_LENGTH];
-	size_t pos = 0, oldpos = 0, i;
-	GSM_Error error;
-
-	GSM_Init(TRUE);
-
-	/* Get model information */
-	error = GSM_GetModel(gsm, model);
-	Print_Error(error);
-
-	/* Empty string */
-	latest_version[0] = 0;
-
-	/* Request information from phone db */
-	sprintf(url, "http://www.gammu.org/support/phones/phonedbxml.php?model=%s", model);
-	PhoneDB.Buffer = NULL;
-	PhoneDB.Used = 0;
-	error = GSM_ReadHTTPFile(url, &PhoneDB);
-	Print_Error(error);
-
-	/* Parse reply */
-	while (pos < PhoneDB.Used) {
-		if (PhoneDB.Buffer[pos] != 10) {
-			pos++;
-			continue;
-		}
-		PhoneDB.Buffer[pos] = 0;
-		if (strstr(PhoneDB.Buffer + oldpos, "<firmware>") == NULL) {
-			pos++;
-			oldpos = pos;
-			continue;
-		}
-		sprintf(latest_version, "%s", strstr(PhoneDB.Buffer + oldpos, "<version>") + 9);
-		for (i = 0; i < strlen(latest_version); i++) {
-			if (latest_version[i] == '<') {
-				latest_version[i] = 0;
-				break;
-			}
-		}
-		pos++;
-		oldpos = pos;
-	}
-	free(PhoneDB.Buffer);
-
-	/* Did we find something? */
-	if (latest_version[0] == 0) {
-		return;
-	}
-
-	/* Get phone firmware version */
-	error = GSM_GetFirmware(gsm, current_version, NULL, NULL);
-	Print_Error(error);
-
-	/* Compare versions */
-	if (!GSM_IsNewerVersion(latest_version, current_version))
-		return;
-
-	/* Print information to user */
-	printf_info("%s", _("Never version of firmware is available!\n"));
-	printf_info(_("Latest version is %s and you run %s.\n"),
-			latest_version, current_version);
-
-	GSM_Terminate();
-}
-
 /**
  * Get's location from OpenCellID.
  */
@@ -199,6 +153,8 @@ void GetLocation(int argc UNUSED, char *argv[]UNUSED)
 	GSM_NetworkInfo netinfo;
 	float latitude, longitude;
 	long int mnc, mcc, lac, cellid, nbSamples, range;
+	char *ret, *old_locale = NULL;
+	gboolean failure = FALSE;
 
 	GSM_Init(TRUE);
 
@@ -206,6 +162,12 @@ void GetLocation(int argc UNUSED, char *argv[]UNUSED)
 	error = GSM_GetNetworkInfo(gsm, &netinfo);
 	Print_Error(error);
 
+	if (netinfo.State == GSM_NoNetwork) {
+		printf_err("%s", _("Not logged to network!\n"));
+		GSM_Terminate();
+		return;
+	}
+
 	/* We need decimal numbers */
 	lac = strtol(netinfo.LAC, NULL, 16);
 	cellid = strtol(netinfo.CID, NULL, 16);
@@ -213,6 +175,7 @@ void GetLocation(int argc UNUSED, char *argv[]UNUSED)
 	/* Split code to country and network */
 	if (sscanf(netinfo.NetworkCode, "%ld %ld", &mcc, &mnc) != 2) {
 		printf_err("%s", _("Wrong network code from phone!\n"));
+		GSM_Terminate();
 		return;
 	}
 
@@ -226,6 +189,12 @@ void GetLocation(int argc UNUSED, char *argv[]UNUSED)
 	error = GSM_ReadHTTPFile(url, &OpenCell);
 	Print_Error(error);
 
+	/* We need to reset numeric locales because we parse floats with . as decimal separator */
+	ret = setlocale(LC_NUMERIC, "C");
+	if (ret != NULL) {
+		old_locale = strdup(ret);
+	}
+
 	/* Parse reply:
 		<?xml version="1.0" encoding="UTF-8"?>
 		<rsp stat="ok">
@@ -234,60 +203,67 @@ void GetLocation(int argc UNUSED, char *argv[]UNUSED)
 	*/
 	if (strstr(OpenCell.Buffer, "stat=\"ok\"") == NULL) {
 		printf_err("%s", _("Request for information from OpenCellID failed!\n"));
-		free(OpenCell.Buffer);
-		return;
+		failure = TRUE;
+		goto done;
 	}
 	pos = strstr(OpenCell.Buffer, "lat=\"");
 	if (pos == NULL) {
 		printf_err("%s", _("Failed to find latitude in OpenCellID reply!\n"));
-		free(OpenCell.Buffer);
-		return;
+		failure = TRUE;
+		goto done;
 	}
 	if (sscanf(pos, "lat=\"%f\"", &latitude) == 0) {
 		printf_err("%s", _("Failed to parse latitude from OpenCellID reply!\n"));
-		free(OpenCell.Buffer);
-		return;
+		failure = TRUE;
+		goto done;
 	}
 	pos = strstr(OpenCell.Buffer, "lon=\"");
 	if (pos == NULL) {
 		printf_err("%s", _("Failed to find longitude in OpenCellID reply!\n"));
-		free(OpenCell.Buffer);
-		return;
+		failure = TRUE;
+		goto done;
 	}
 	if (sscanf(pos, "lon=\"%f\"", &longitude) == 0) {
 		printf_err("%s", _("Failed to parse longitude from OpenCellID reply!\n"));
-		free(OpenCell.Buffer);
-		return;
+		failure = TRUE;
+		goto done;
 	}
 	pos = strstr(OpenCell.Buffer, "range=\"");
 	if (pos == NULL) {
 		printf_err("%s", _("Failed to find range in OpenCellID reply!\n"));
-		free(OpenCell.Buffer);
-		return;
+		failure = TRUE;
+		goto done;
 	}
 	if (sscanf(pos, "range=\"%ld\"", &range) == 0) {
 		printf_err("%s", _("Failed to parse range from OpenCellID reply!\n"));
-		free(OpenCell.Buffer);
-		return;
+		failure = TRUE;
+		goto done;
 	}
 	pos = strstr(OpenCell.Buffer, "nbSamples=\"");
 	if (pos == NULL) {
 		printf_err("%s", _("Failed to find nbSamples in OpenCellID reply!\n"));
-		free(OpenCell.Buffer);
-		return;
+		failure = TRUE;
+		goto done;
 	}
 	if (sscanf(pos, "nbSamples=\"%ld\"", &nbSamples) == 0) {
 		printf_err("%s", _("Failed to parse nbSamples from OpenCellID reply!\n"));
-		free(OpenCell.Buffer);
-		return;
+		failure = TRUE;
+		goto done;
 	}
+
+done:
+	if (old_locale != NULL) {
+		setlocale(LC_NUMERIC, old_locale);
+		free(old_locale);
+	}
+	if (!failure) {
+		printf(LISTFORMAT "%f\n", _("Latitude"), latitude);
+		printf(LISTFORMAT "%f\n", _("Longitude"), longitude);
+		printf(LISTFORMAT "%ld\n", _("Range"), range);
+		printf(LISTFORMAT "%ld\n", _("Number of samples"), nbSamples);
+	}
+
 	free(OpenCell.Buffer);
-
-	printf(LISTFORMAT "%f\n", _("Latitude"), latitude);
-	printf(LISTFORMAT "%f\n", _("Longitude"), longitude);
-	printf(LISTFORMAT "%ld\n", _("Range"), range);
-	printf(LISTFORMAT "%ld\n", _("Number of samples"), nbSamples);
-
 	GSM_Terminate();
 }
 
@@ -383,12 +359,15 @@ void Identify(int argc, char *argv[])
 void NetworkInfo(int argc UNUSED, char *argv[] UNUSED)
 {
 	GSM_NetworkInfo		NetInfo;
+	GSM_Error error;
 
 	GSM_Init(TRUE);
 
-	if (GSM_GetNetworkInfo(gsm,&NetInfo)==ERR_NONE) {
-		PrintNetworkInfo(NetInfo);
-	}
+	error = GSM_GetNetworkInfo(gsm,&NetInfo);
+	Print_Error(error);
+
+	PrintNetworkInfo(NetInfo);
+
 	GSM_Terminate();
 }
 
