@@ -27,7 +27,7 @@ void GetMMSFolders(int argc UNUSED, char *argv[] UNUSED)
 
 	for (i=0;i<folders.Number;i++) {
 		printf("%i. \"%s\"",i+1,DecodeUnicodeConsole(folders.Folder[i].Name));
-		if (folders.Folder[i].InboxFolder) printf(_(", Inbox folder"));
+		if (folders.Folder[i].InboxFolder) printf("%s", _(", Inbox folder"));
 		printf("\n");
 	}
 
@@ -46,7 +46,7 @@ void DecodeMMSFile(GSM_File *file, int num)
 	GSM_CalendarEntry 		Calendar;
 	GSM_ToDoEntry 			ToDo;
 
-	if (num != -1 && answer_yes(_("Do you want to save this MMS file?"))) {
+	if (num != -1 && answer_yes("%s", _("Do you want to save this MMS file?"))) {
 		sprintf(buff,"%i_0",num);
 		file2 = fopen(buff,"wb");
 		if (fwrite(file->Buffer, 1, file->Used, file2) != file->Used) {
@@ -70,7 +70,7 @@ void DecodeMMSFile(GSM_File *file, int num)
 	if (UnicodeLength(info.Source) != 0) {
 		printf(LISTFORMAT, _("Sender"));
 		switch (info.SourceType) {
-			case MMSADDRESS_PHONE: printf(_("phone ")); break;
+			case MMSADDRESS_PHONE: printf("%s", _("phone ")); break;
 			default: 				 break;
 		}
 		printf("%s\n",DecodeUnicodeString(info.Source));
@@ -78,7 +78,7 @@ void DecodeMMSFile(GSM_File *file, int num)
 	if (UnicodeLength(info.Destination) != 0) {
 		printf(LISTFORMAT, _("Recipient"));
 		switch (info.DestinationType) {
-			case MMSADDRESS_PHONE: printf(_("phone ")); break;
+			case MMSADDRESS_PHONE: printf("%s", _("phone ")); break;
 			default: 				 break;
 		}
 		printf("%s\n",DecodeUnicodeString(info.Destination));
@@ -86,7 +86,7 @@ void DecodeMMSFile(GSM_File *file, int num)
 	if (UnicodeLength(info.CC) != 0) {
 		printf(LISTFORMAT, _("CC"));
 		switch (info.CCType) {
-			case MMSADDRESS_PHONE: printf(_("phone ")); break;
+			case MMSADDRESS_PHONE: printf("%s", _("phone ")); break;
 			default: 				 break;
 		}
 		printf("%s\n",DecodeUnicodeString(info.CC));
@@ -127,7 +127,7 @@ void DecodeMMSFile(GSM_File *file, int num)
 			error = GSM_DecodeVCALENDAR_VTODO(GSM_GetDebug(gsm), info.Entries[i].File.Buffer, &Pos, &Calendar, &ToDo, Nokia_VCalendar, Nokia_VToDo);
 			if (error == ERR_NONE) PrintCalendar(&Calendar);
 		}
-		if (num != -1 && answer_yes(_("Do you want to save this attachment?"))) {
+		if (num != -1 && answer_yes("%s", _("Do you want to save this attachment?"))) {
 			sprintf(buff,"%i_%i_%s",num,i+1,DecodeUnicodeString(info.Entries[i].File.Name));
 			file2 = fopen(buff,"wb");
 			if (fwrite(info.Entries[i].File.Buffer, 1, info.Entries[i].File.Used, file2) != info.Entries[i].File.Used) {
