@@ -41,7 +41,7 @@ void NokiaComposer(int argc UNUSED, char *argv[])
 
 	if (ringtone.Format != RING_NOTETONE) {
 		printf("%s\n", _("It can be RTTL ringtone only used with this option"));
-		Terminate(3);
+		Terminate(2);
 	}
 
 	started = FALSE;
@@ -121,7 +121,7 @@ void NokiaComposer(int argc UNUSED, char *argv[])
 	      				case Note_H  :			printf("7");break;
 	      				default      :			printf("0");break;
 				}
-				if (Note->DurationSpec == DottedNote) printf(_("(longer)"));
+				if (Note->DurationSpec == DottedNote) printf("%s", _("(longer)"));
 	    			switch (Note->Note) {
       					case Note_Cis: case Note_Dis:
       					case Note_Fis: case Note_Gis:
@@ -176,11 +176,15 @@ void NokiaSecurityCode(int argc, char *argv[])
 	GSM_Init(TRUE);
 
 #ifdef GSM_ENABLE_NOKIA_DCT3
-	DCT3GetSecurityCode(argc,argv);
+	if (CheckDCT3Only() != ERR_NOTSUPPORTED) {
+		DCT3GetSecurityCode(argc,argv);
+	}
 #endif
 #ifdef GSM_ENABLE_NOKIA_DCT4
-/* 	DCT4ResetSecurityCode(argc, argv); */
-	DCT4GetSecurityCode(argc,argv);
+	if (CheckDCT4Only() != ERR_NOTSUPPORTED) {
+	/* 	DCT4ResetSecurityCode(argc, argv); */
+		DCT4GetSecurityCode(argc,argv);
+	}
 #endif
 
 	GSM_Terminate();
@@ -191,10 +195,14 @@ void NokiaSetPhoneMenus(int argc, char *argv[])
 	GSM_Init(TRUE);
 
 #ifdef GSM_ENABLE_NOKIA_DCT3
-	DCT3SetPhoneMenus (argc, argv);
+	if (CheckDCT3Only() != ERR_NOTSUPPORTED) {
+		DCT3SetPhoneMenus (argc, argv);
+	}
 #endif
 #ifdef GSM_ENABLE_NOKIA_DCT4
-	DCT4SetPhoneMenus (argc, argv);
+	if (CheckDCT4Only() != ERR_NOTSUPPORTED) {
+		DCT4SetPhoneMenus (argc, argv);
+	}
 #endif
 
 	GSM_Terminate();
@@ -205,10 +213,14 @@ void NokiaSelfTests(int argc, char *argv[])
 	GSM_Init(TRUE);
 
 #ifdef GSM_ENABLE_NOKIA_DCT3
-	DCT3SelfTests(argc, argv);
+	if (CheckDCT3Only() != ERR_NOTSUPPORTED) {
+		DCT3SelfTests(argc, argv);
+	}
 #endif
 #ifdef GSM_ENABLE_NOKIA_DCT4
-	DCT4SelfTests(argc, argv);
+	if (CheckDCT4Only() != ERR_NOTSUPPORTED) {
+		DCT4SelfTests(argc, argv);
+	}
 #endif
 
 	GSM_Terminate();
@@ -423,9 +435,9 @@ void NokiaAddPlayLists(int argc UNUSED, char *argv[] UNUSED)
 	    	Print_Error(error);
 	}
 	if (error == ERR_FILENOTEXIST) {
-		printf("%s\n", _("Your phone model is not supported. Please report it to authors (see <http://cihar.com/gammu/report>). Thank you."));
+		printf("%s\n", _("Your phone model is not supported. Please report it to authors (see <http://wammu.eu/support/bugs/>). Thank you."));
 		GSM_Terminate();
-		Terminate(3);
+		Terminate(2);
 	} else if (error != ERR_EMPTY) {
 	    	Print_Error(error);
 	}
@@ -534,21 +546,30 @@ void NokiaAddFile(int argc, char *argv[])
 	}
 	if (!Found) {
 		printf(_("What folder type (\"%s\") ?\n"),argv[2]);
-		Terminate(3);
+		Terminate(2);
 	}
 
 	if (strcasecmp(argv[2],"Application") == 0 || strcasecmp(argv[2],"Game") == 0) {
-		sprintf(buffer,"%s.jad",argv[3]);
-		file = fopen(buffer,"rb");
-		if (file == NULL) Print_Error(ERR_CANTOPENFILE);
+		sprintf(buffer, "%s.jad", argv[3]);
+		file = fopen(buffer, "rb");
+		if (file == NULL) {
+			printf_err(_("Can not open file %s\n"), buffer);
+			Print_Error(ERR_CANTOPENFILE);
+		}
 		fclose(file);
-		sprintf(buffer,"%s.jar",argv[3]);
-		file = fopen(buffer,"rb");
-		if (file == NULL) Print_Error(ERR_CANTOPENFILE);
+		sprintf(buffer, "%s.jar", argv[3]);
+		file = fopen(buffer, "rb");
+		if (file == NULL) {
+			printf_err(_("Can not open file %s\n"), buffer);
+			Print_Error(ERR_CANTOPENFILE);
+		}
 		fclose(file);
 	} else {
 		file = fopen(argv[3],"rb");
-		if (file == NULL) Print_Error(ERR_CANTOPENFILE);
+		if (file == NULL) {
+			printf_err(_("Can not open file %s\n"), argv[3]);
+			Print_Error(ERR_CANTOPENFILE);
+		}
 		fclose(file);
 	}
 
@@ -569,7 +590,7 @@ void NokiaAddFile(int argc, char *argv[])
 		if (!Found) {
 			printf("%s\n", _("Folder not found. Probably function not supported!"));
 			GSM_Terminate();
-			Terminate(3);
+			Terminate(2);
 		}
 	} else if (GSM_IsPhoneFeatureAvailable(GSM_GetModelInfo(gsm), F_FILES2)) {
 		i = 0;
@@ -590,7 +611,7 @@ void NokiaAddFile(int argc, char *argv[])
 		}
 	}
 	if (!Found) {
-		fprintf(stderr, _("Searching for phone folder: "));
+		fprintf(stderr, "%s", _("Searching for phone folder: "));
 		while (1) {
 			error = GSM_GetNextFileFolder(gsm,&Files,Start);
 			if (error == ERR_EMPTY) break;
@@ -643,7 +664,7 @@ void NokiaAddFile(int argc, char *argv[])
 	if (!Found) {
 		printf("%s\n", _("Folder not found. Probably function not supported!"));
 		GSM_Terminate();
-		Terminate(3);
+		Terminate(2);
 	}
 	File.Buffer 	= NULL;
 	File.Protected  = FALSE;
@@ -923,7 +944,7 @@ void NokiaAddFile(int argc, char *argv[])
 						continue;
 					}
 					printf(_("Parameter \"%s\" unknown\n"),argv[j]);
-					Terminate(3);
+					Terminate(2);
 				case 1:
 					strcpy(buffer,argv[j]);
 					nextlong = 0;
@@ -932,7 +953,7 @@ void NokiaAddFile(int argc, char *argv[])
 			}
 			if (nextlong!=0) {
 				printf_err("%s\n", _("Parameter missing!"));
-				Terminate(3);
+				Terminate(2);
 			}
 		}
 	}
@@ -962,10 +983,14 @@ void NokiaGetADC(int argc, char *argv[])
 	GSM_Init(TRUE);
 
 #ifdef GSM_ENABLE_NOKIA_DCT3
-	DCT3GetADC(argc,argv);
+	if (CheckDCT3Only() != ERR_NOTSUPPORTED) {
+		DCT3GetADC(argc,argv);
+	}
 #endif
 #ifdef GSM_ENABLE_NOKIA_DCT4
-	DCT4GetADC(argc, argv);
+	if (CheckDCT4Only() != ERR_NOTSUPPORTED) {
+		DCT4GetADC(argc, argv);
+	}
 #endif
 
 	GSM_Terminate();
@@ -976,10 +1001,14 @@ void NokiaDisplayTest(int argc, char *argv[])
 	GSM_Init(TRUE);
 
 #ifdef GSM_ENABLE_NOKIA_DCT3
-	DCT3DisplayTest(argc,argv);
+	if (CheckDCT3Only() != ERR_NOTSUPPORTED) {
+		DCT3DisplayTest(argc,argv);
+	}
 #endif
 #ifdef GSM_ENABLE_NOKIA_DCT4
-	DCT4DisplayTest(argc, argv);
+	if (CheckDCT4Only() != ERR_NOTSUPPORTED) {
+		DCT4DisplayTest(argc, argv);
+	}
 #endif
 
 	GSM_Terminate();
@@ -990,10 +1019,14 @@ void NokiaGetT9(int argc, char *argv[])
 	GSM_Init(TRUE);
 
 #ifdef GSM_ENABLE_NOKIA_DCT3
-	DCT3GetT9(argc,argv);
+	if (CheckDCT3Only() != ERR_NOTSUPPORTED) {
+		DCT3GetT9(argc,argv);
+	}
 #endif
 #ifdef GSM_ENABLE_NOKIA_DCT4
-	DCT4GetT9(argc, argv);
+	if (CheckDCT4Only() != ERR_NOTSUPPORTED) {
+		DCT4GetT9(argc, argv);
+	}
 #endif
 
 	GSM_Terminate();
@@ -1004,10 +1037,14 @@ void NokiaVibraTest(int argc, char *argv[])
 	GSM_Init(TRUE);
 
 #ifdef GSM_ENABLE_NOKIA_DCT3
-	DCT3VibraTest(argc,argv);
+	if (CheckDCT3Only() != ERR_NOTSUPPORTED) {
+		DCT3VibraTest(argc,argv);
+	}
 #endif
 #ifdef GSM_ENABLE_NOKIA_DCT4
-	DCT4VibraTest(argc, argv);
+	if (CheckDCT4Only() != ERR_NOTSUPPORTED) {
+		DCT4VibraTest(argc, argv);
+	}
 #endif
 
 	GSM_Terminate();
