@@ -50,7 +50,7 @@ typedef struct {
 	OneConnectionInfo Connections[5];
 } OneDeviceInfo;
 
-bool SearchOutput;
+gboolean SearchOutput;
 
 /**
  * Like printf, but only when output from searching is enabled.
@@ -131,10 +131,10 @@ THREAD_RETURN SearchPhoneThread(void * arg)
 		/* Configure the tested state machine */
 		smcfg->Device = strdup(Info->Device);
 		smcfg->Connection = strdup(Info->Connections[j].Connection);
-		smcfg->SyncTime = strdup("no");
+		smcfg->SyncTime = FALSE;
 		smcfg->Model[0] = 0;
-		smcfg->LockDevice = strdup("no");
-		smcfg->StartInfo = strdup("no");
+		smcfg->LockDevice = FALSE;
+		smcfg->StartInfo = FALSE;
 
 		/* We have only one configured connection */
 		GSM_SetConfigNum(search_gsm, 1);
@@ -179,14 +179,14 @@ void MakeSearchThread(int i)
 	if (pthread_create
 	    (&Threads[i], NULL, SearchPhoneThread,
 	     &SearchDevices[i]) != 0) {
-		fprintf(stderr, _("Error creating thread\n"));
+		fprintf(stderr, "%s", _("Error creating thread\n"));
 	}
 #else
 	Threads[i] = CreateThread((LPSECURITY_ATTRIBUTES) NULL, 0,
 			 (LPTHREAD_START_ROUTINE) SearchPhoneThread,
 			 &SearchDevices[i], 0, NULL);
 	if (Threads[i] 	== NULL) {
-		fprintf(stderr, _("Error creating thread\n"));
+		fprintf(stderr, "%s", _("Error creating thread\n"));
 	}
 #endif
 }
@@ -200,9 +200,9 @@ void SearchPhone(int argc, char *argv[])
 #endif
 
 
-	SearchOutput = false;
+	SearchOutput = FALSE;
 	if (argc == 3 && strcasecmp(argv[2], "-debug") == 0)
-		SearchOutput = true;
+		SearchOutput = TRUE;
 
 #ifdef WIN32
 	SearchDevices[dev].Device[0] = 0;
