@@ -19,6 +19,9 @@
 #include <gammu-wap.h>
 #include <gammu-settings.h>
 #include <gammu-ringtone.h>
+#include <gammu-config.h>
+
+#ifdef GSM_ENABLE_BACKUP
 
 /**
  * Maximal number of SMSes in backup.
@@ -49,7 +52,7 @@ typedef struct {
  *
  * \return Error code
  */
-extern GSM_Error GSM_ReadSMSBackupFile(char *FileName, GSM_SMS_Backup * backup);
+GSM_Error GSM_ReadSMSBackupFile(char *FileName, GSM_SMS_Backup * backup);
 
 /**
  * Adds data to SMS backup file.
@@ -61,7 +64,7 @@ extern GSM_Error GSM_ReadSMSBackupFile(char *FileName, GSM_SMS_Backup * backup);
  *
  * \return Error code
  */
-extern GSM_Error GSM_AddSMSBackupFile(char *FileName, GSM_SMS_Backup * backup);
+GSM_Error GSM_AddSMSBackupFile(char *FileName, GSM_SMS_Backup * backup);
 
 /**
  * Clears SMS backup structure
@@ -475,6 +478,9 @@ void GSM_GetBackupFormatFeatures(GSM_BackupFormat Format,
  */
 void GSM_GetBackupFileFeatures(GSM_BackupFormat Format, GSM_Backup_Info * info,
 			       GSM_Backup * backup);
+
+#endif
+
 #endif
 
 /* Editor configuration
