@@ -71,7 +71,7 @@ void INI_Free(INI_Section * head);
  *
  * \return Error code
  */
-GSM_Error INI_ReadFile(const char *FileName, bool Unicode,
+GSM_Error INI_ReadFile(const char *FileName, gboolean Unicode,
 		       INI_Section ** result);
 
 /**
@@ -89,7 +89,7 @@ GSM_Error INI_ReadFile(const char *FileName, bool Unicode,
  */
 INI_Entry *INI_FindLastSectionEntry(INI_Section * file_info,
 				    const unsigned char *section,
-				    const bool Unicode);
+				    const gboolean Unicode);
 
 /**
  * Returns value of INI file entry.
@@ -107,7 +107,54 @@ INI_Entry *INI_FindLastSectionEntry(INI_Section * file_info,
  */
 unsigned char *INI_GetValue(INI_Section * file_info,
 			    const unsigned char *section,
-			    const unsigned char *key, const bool Unicode);
+			    const unsigned char *key, const gboolean Unicode);
+
+/**
+ * Returns integer value from configuration. The file is automatically
+ * handled as not unicode.
+ *
+ * \param cfg File data as returned by \ref INI_ReadFile.
+ * \param section Section to scan.
+ * \param key Name of key to read.
+ * \param fallback Fallback value.
+ *
+ * \return Key value or fallback in case of failure.
+ */
+int INI_GetInt(INI_Section *cfg,
+	const unsigned char *section,
+	const unsigned char *key,
+	int fallback);
+
+/**
+ * Returns boolean value from configuration. The file is automatically
+ * handled as not unicode.
+ *
+ * \param cfg File data as returned by \ref INI_ReadFile.
+ * \param section Section to scan.
+ * \param key Name of key to read.
+ * \param fallback Fallback value.
+ *
+ * \return Key value or fallback in case of failure.
+ */
+gboolean INI_GetBool(INI_Section *cfg,
+	const unsigned char *section,
+	const unsigned char *key,
+	gboolean fallback);
+
+
+/**
+ * Checks whether value can be evaluated as true.
+ *
+ * It just takes the string and checks whether there is true/yes/1.
+ *
+ * \ingroup INI
+ *
+ * \param value String to parse.
+ *
+ * \return Boolean value.
+ */
+gboolean INI_IsTrue(const char *value);
+
 #endif
 
 /* Editor configuration
