@@ -70,7 +70,7 @@
  *
  * \ingroup Limits
  */
-#define GSM_MAX_NUMBER_LENGTH 150
+#define GSM_MAX_NUMBER_LENGTH 200
 
 /**
  * Maximal count of todo and calendar notes.
@@ -165,11 +165,18 @@
 #define GSM_MAX_UDH_LENGTH 140
 
 /**
- * Maximal length of text in standard SMS.
+ * Maximal length of text in SMS.
  *
  * \ingroup Limits
  */
-#define GSM_MAX_SMS_LENGTH 160
+#define GSM_MAX_SMS_LENGTH 650
+
+/**
+ * Maximal length of text in standard 7-bit SMS.
+ *
+ * \ingroup Limits
+ */
+#define GSM_MAX_SMS_CHARS_LENGTH 160
 
 /**
  * Maximal length of 8-bit text in SMS.
@@ -274,14 +281,14 @@
  *
  * \ingroup Limits
  */
-#define GSM_MAX_FILENAME_LENGTH 149
+#define GSM_MAX_FILENAME_LENGTH 256
 
 /**
  * Maximal length of full file name (including path).
  *
  * \ingroup Limits
  */
-#define GSM_MAX_FILENAME_ID_LENGTH 399
+#define GSM_MAX_FILENAME_ID_LENGTH 4096
 
 /**
  * Maximal number of features per phone.
@@ -290,6 +297,13 @@
  */
 #define GSM_MAX_PHONE_FEATURES 20
 
+/**
+ * Maximal length of USSD text.
+ *
+ * \ingroup Limits
+ */
+#define GSM_MAX_USSD_LENGTH 999
+
 #endif
 
 /* Editor configuration
