@@ -15,6 +15,7 @@
 #include <gammu-wap.h>
 #include <gammu-calendar.h>
 #include <gammu-file.h>
+#include <gammu-debug.h>
 
 /**
  * \defgroup Message Messages
@@ -45,15 +46,58 @@
  * \ingroup Message
  */
 
+/**
+ * MMS message class.
+ */
+typedef enum {
+	/**
+	 * None class specified.
+	 */
+	GSM_MMS_None = 0,
+	/**
+	 * Personal message.
+	 */
+	GSM_MMS_Personal = 1,
+	/**
+	 * Advertisement message.
+	 */
+	GSM_MMS_Advertisement,
+	/**
+	 * Informational message.
+	 */
+	GSM_MMS_Info,
+	/**
+	 * Automatic message class.
+	 */
+	GSM_MMS_Auto,
+} GSM_MMS_Class;
+
 /**
  * MMS indicator data.
  *
  * \ingroup MMS
  */
 typedef struct {
+	/**
+	 * Message address (URL for download).
+	 */
 	char Address[500];
+	/**
+	 * Message title (subject).
+	 */
 	char Title[200];
+	/**
+	 * Message sender.
+	 */
 	char Sender[200];
+	/**
+	 * Message size, if 0 it won't be decoded or was not decoded.
+	 */
+	size_t MessageSize;
+	/**
+	 * Class of a message.
+	 */
+	GSM_MMS_Class Class;
 } GSM_MMSIndicator;
 
 /**
@@ -117,7 +161,7 @@ typedef struct {
 	/**
 	 * Message text.
 	 */
-	unsigned char Text[2000];
+	unsigned char Text[2 * (GSM_MAX_USSD_LENGTH + 1)];
 	/**
 	 * Message status.
 	 */
@@ -386,7 +430,7 @@ typedef struct {
 	/**
 	 * Whether to reject duplicates.
 	 */
-	bool RejectDuplicates;
+	gboolean RejectDuplicates;
 	/**
 	 * UDH (User Data Header)
 	 */
@@ -419,7 +463,7 @@ typedef struct {
 	/**
 	 * For saved SMS: whether SMS is really in Inbox.
 	 */
-	bool InboxFolder;
+	gboolean InboxFolder;
 	/**
 	 * Length of the SMS message.
 	 */
@@ -459,9 +503,9 @@ typedef struct {
 	/**
 	 * Indicates whether "Reply via same center" is set.
 	 */
-	bool ReplyViaSameSMSC;
+	gboolean ReplyViaSameSMSC;
 	/**
-	 * SMS class.
+	 * SMS class (0 is flash SMS, 1 is normal one).
 	 */
 	signed char Class;
 	/**
@@ -543,35 +587,53 @@ typedef struct {
 	unsigned char TPPID;
 } GSM_SMSMessageLayout;
 
+/**
+ * Decodes PDU data.
+ *
+ * \param di Debug information structure.
+ * \param SMS Pointer where to store parsed message.
+ * \param buffer PDU data.
+ * \param length Length of PDU data.
+ * \param final_pos Optional pointer where end position will be stored.
+ * \param SMSC Whether PDU includes SMSC data.
+ *
+ * \ingroup SMS
+ */
+GSM_Error GSM_DecodePDUFrame(GSM_Debug_Info *di, GSM_SMSMessage *SMS,
+			const unsigned char *buffer, size_t length,
+			size_t *final_pos, gboolean SMSC);
+
 /**
  * Decodes SMS frame.
  *
  * \ingroup SMS
  */
-GSM_Error GSM_DecodeSMSFrame(GSM_SMSMessage * SMS, unsigned char *buffer,
+GSM_Error GSM_DecodeSMSFrame(GSM_Debug_Info * di, GSM_SMSMessage * SMS,
+			     unsigned char *buffer,
 			     GSM_SMSMessageLayout Layout);
 
 /**
  * Finds out coding type based on TPDCS header byte as defined by GSM
  * 03.38.
  */
-GSM_Coding_Type GSM_GetMessageCoding(const char TPDCS);
+GSM_Coding_Type GSM_GetMessageCoding(GSM_Debug_Info * di, const char TPDCS);
 
 /**
  * Encodes SMS frame.
  *
  * \ingroup SMS
  */
-GSM_Error GSM_EncodeSMSFrame(GSM_SMSMessage * SMS, unsigned char *buffer,
-			     GSM_SMSMessageLayout Layout, int *length,
-			     bool clear);
+GSM_Error GSM_EncodeSMSFrame(GSM_Debug_Info * di, GSM_SMSMessage * SMS,
+			     unsigned char *buffer, GSM_SMSMessageLayout Layout,
+			     int *length, gboolean clear);
 
 /**
  * Decodes SMS frame for status report.
  *
  * \ingroup SMS
  */
-GSM_Error GSM_DecodeSMSFrameStatusReportData(GSM_SMSMessage * SMS,
+GSM_Error GSM_DecodeSMSFrameStatusReportData(GSM_Debug_Info * di,
+					     GSM_SMSMessage * SMS,
 					     unsigned char *buffer,
 					     GSM_SMSMessageLayout Layout);
 
@@ -580,7 +642,8 @@ GSM_Error GSM_DecodeSMSFrameStatusReportData(GSM_SMSMessage * SMS,
  *
  * \ingroup SMS
  */
-GSM_Error GSM_DecodeSMSFrameText(GSM_SMSMessage * SMS, unsigned char *buffer,
+GSM_Error GSM_DecodeSMSFrameText(GSM_Debug_Info * di, GSM_SMSMessage * SMS,
+				 unsigned char *buffer,
 				 GSM_SMSMessageLayout Layout);
 
 /**
@@ -588,14 +651,14 @@ GSM_Error GSM_DecodeSMSFrameText(GSM_SMSMessage * SMS, unsigned char *buffer,
  *
  * \ingroup SMS
  */
-void GSM_DecodeUDHHeader(GSM_UDHHeader * UDH);
+void GSM_DecodeUDHHeader(GSM_Debug_Info * di, GSM_UDHHeader * UDH);
 
 /**
  * Encodes UDH header.
  *
  * \ingroup SMS
  */
-void GSM_EncodeUDHHeader(GSM_UDHHeader * UDH);
+void GSM_EncodeUDHHeader(GSM_Debug_Info * di, GSM_UDHHeader * UDH);
 
 /**
  * Sets default content for SMS except for changing locations.
@@ -607,7 +670,6 @@ void GSM_EncodeUDHHeader(GSM_UDHHeader * UDH);
  */
 void GSM_SetDefaultReceivedSMSData(GSM_SMSMessage * SMS);
 
-
 /**
  * Sets default content for SMS. Use this for clearing structure.
  *
@@ -626,11 +688,11 @@ typedef struct {
 	/**
 	 * Whether it is inbox.
 	 */
-	bool InboxFolder;
+	gboolean InboxFolder;
 	/**
 	 * Whether it is outbox.
 	 */
-	bool OutboxFolder;
+	gboolean OutboxFolder;
 	/**
 	 * Where exactly it's saved.
 	 */
@@ -654,7 +716,7 @@ typedef struct {
 	/**
  	 * Number of SMS folders.
 	 */
-	unsigned char Number;
+	int Number;
 } GSM_SMSFolders;
 
 /**
@@ -679,7 +741,8 @@ typedef struct {
  *
  * \ingroup SMS
  */
-bool GSM_DecodeSiemensOTASMS(GSM_SiemensOTASMSInfo * Info,
+gboolean GSM_DecodeSiemensOTASMS(GSM_Debug_Info * di,
+			     GSM_SiemensOTASMSInfo * Info,
 			     GSM_SMSMessage * SMS);
 
 /**
@@ -690,10 +753,8 @@ bool GSM_DecodeSiemensOTASMS(GSM_SiemensOTASMSInfo * Info,
 typedef struct {
 	/**
 	 * Number of messages.
-	 *
-	 * @bug: Should be changed to unsigned int on API change.
 	 */
-	unsigned char Number;
+	int Number;
 	/**
 	 * Array of SMSes.
 	 */
@@ -709,7 +770,7 @@ typedef struct {
 	/**
 	 * Whether it is really inbox.
 	 */
-	bool InboxFolder;
+	gboolean InboxFolder;
 	/**
   	 * Name for MMS folder.
 	 */
@@ -872,6 +933,9 @@ typedef enum {
 	SMS_EMSFixedBitmap,
 	SMS_EMSVariableBitmap,
 	SMS_EMSVariableBitmapLong,
+	/**
+	 * MMS message indicator.
+	 */
 	SMS_MMSIndicatorLong,
 	SMS_WAPIndicatorLong,
 	/**
@@ -907,18 +971,18 @@ typedef struct {
 	GSM_CalendarEntry *Calendar;
 	GSM_ToDoEntry *ToDo;
 	GSM_File *File;
-	bool Protected;
+	gboolean Protected;
 
 	unsigned char *Buffer;
-	bool Left;
-	bool Right;
-	bool Center;
-	bool Large;
-	bool Small;
-	bool Bold;
-	bool Italic;
-	bool Underlined;
-	bool Strikethrough;
+	gboolean Left;
+	gboolean Right;
+	gboolean Center;
+	gboolean Large;
+	gboolean Small;
+	gboolean Bold;
+	gboolean Italic;
+	gboolean Underlined;
+	gboolean Strikethrough;
 
 	/* Return values */
 	int RingtoneNotes;
@@ -931,10 +995,10 @@ typedef struct {
  */
 typedef struct {
 	int EntriesNum;
-	bool UnicodeCoding;
+	gboolean UnicodeCoding;
 	int Class;
 	unsigned char ReplaceMessage;
-	bool Unknown;
+	gboolean Unknown;
 	GSM_MultiPartSMSEntry Entries[GSM_MAX_MULTI_SMS];
 } GSM_MultiPartSMSInfo;
 
@@ -948,7 +1012,7 @@ typedef struct {
 GSM_Error PHONE_EncodeSMSFrame(GSM_StateMachine * s, GSM_SMSMessage * SMS,
 			       unsigned char *buffer,
 			       GSM_SMSMessageLayout Layout, int *length,
-			       bool clear);
+			       gboolean clear);
 
 /**
  * Encodes multi part SMS from "readable" format.
@@ -957,7 +1021,8 @@ GSM_Error PHONE_EncodeSMSFrame(GSM_StateMachine * s, GSM_SMSMessage * SMS,
  *
  * \ingroup SMS
  */
-GSM_Error GSM_EncodeMultiPartSMS(GSM_MultiPartSMSInfo * Info,
+GSM_Error GSM_EncodeMultiPartSMS(GSM_Debug_Info * di,
+				 GSM_MultiPartSMSInfo * Info,
 				 GSM_MultiSMSMessage * SMS);
 
 /**
@@ -965,8 +1030,9 @@ GSM_Error GSM_EncodeMultiPartSMS(GSM_MultiPartSMSInfo * Info,
  *
  * \ingroup SMS
  */
-bool GSM_DecodeMultiPartSMS(GSM_MultiPartSMSInfo * Info,
-			    GSM_MultiSMSMessage * SMS, bool ems);
+gboolean GSM_DecodeMultiPartSMS(GSM_Debug_Info * di,
+			    GSM_MultiPartSMSInfo * Info,
+			    GSM_MultiSMSMessage * SMS, gboolean ems);
 
 /**
  * Clears @ref GSM_MultiPartSMSInfo to default values.
@@ -989,8 +1055,9 @@ void GSM_FreeMultiPartSMSInfo(GSM_MultiPartSMSInfo * Info);
  *
  * \ingroup SMS
  */
-GSM_Error GSM_LinkSMS(GSM_MultiSMSMessage ** INPUT,
-		      GSM_MultiSMSMessage ** OUTPUT, bool ems);
+GSM_Error GSM_LinkSMS(GSM_Debug_Info * di,
+		      GSM_MultiSMSMessage ** INPUT,
+		      GSM_MultiSMSMessage ** OUTPUT, gboolean ems);
 
 /**
  * MMS address type.
@@ -1056,11 +1123,11 @@ typedef struct {
 	 */
 	unsigned char MSGType[50];
 
-	bool DateTimeAvailable;
+	gboolean DateTimeAvailable;
 	GSM_DateTime DateTime;
 
-	bool MMSReportAvailable;
-	bool MMSReport;
+	gboolean MMSReportAvailable;
+	gboolean MMSReport;
 	/**
 	 * Subparts.
 	 */
@@ -1072,7 +1139,7 @@ typedef struct {
  *
  * \ingroup MMS
  */
-GSM_Error GSM_DecodeMMSFileToMultiPart(GSM_File * file,
+GSM_Error GSM_DecodeMMSFileToMultiPart(GSM_Debug_Info * di, GSM_File * file,
 				       GSM_EncodedMultiPartMMSInfo * info);
 
 /**
@@ -1086,6 +1153,7 @@ GSM_Error GSM_ClearMMSMultiPart(GSM_EncodedMultiPartMMSInfo * info);
  * Gets SMS Service Center number and SMS settings.
  *
  * \param s State machine pointer.
+ * \param[in,out] smsc SMSC structure, should contain location.
  *
  * \return Error code.
  *
@@ -1097,6 +1165,7 @@ GSM_Error GSM_GetSMSC(GSM_StateMachine * s, GSM_SMSC * smsc);
  * Sets SMS Service Center number and SMS settings.
  *
  * \param s State machine pointer.
+ * \param[in] smsc SMSC structure.
  *
  * \return Error code.
  *
@@ -1109,6 +1178,7 @@ GSM_Error GSM_SetSMSC(GSM_StateMachine * s, GSM_SMSC * smsc);
  * both SIM and phone).
  *
  * \param s State machine pointer.
+ * \param[out] status Pointer to SMS status structure.
  *
  * \return Error code.
  *
@@ -1120,6 +1190,8 @@ GSM_Error GSM_GetSMSStatus(GSM_StateMachine * s, GSM_SMSMemoryStatus * status);
  * Reads SMS message.
  *
  * \param s State machine pointer.
+ * \param[in,out] sms SMS message data read from phone, location and
+ * folder should be set.
  *
  * \return Error code.
  *
@@ -1135,17 +1207,22 @@ GSM_Error GSM_GetSMS(GSM_StateMachine * s, GSM_MultiSMSMessage * sms);
  * in phone. To do so, you have to call \ref GSM_GetSMS.
  *
  * \param s State machine pointer.
+ * \param[in,out] sms SMS message data read from phone, for subsequent
+ * reads, location and folder might be used by phone driver to determine
+ * reading state.
+ * \param[in] start Whether we start reading from beginning.
  *
  * \return Error code.
  *
  * \ingroup SMS
  */
 GSM_Error GSM_GetNextSMS(GSM_StateMachine * s, GSM_MultiSMSMessage * sms,
-			 bool start);
+			 gboolean start);
 /**
  * Sets SMS.
  *
  * \param s State machine pointer.
+ * \param[in] sms SMS message data.
  *
  * \return Error code.
  *
@@ -1157,6 +1234,7 @@ GSM_Error GSM_SetSMS(GSM_StateMachine * s, GSM_SMSMessage * sms);
  * Adds SMS to specified folder.
  *
  * \param s State machine pointer.
+ * \param[in,out] sms SMS message data, location will be updated.
  *
  * \return Error code.
  *
@@ -1168,6 +1246,7 @@ GSM_Error GSM_AddSMS(GSM_StateMachine * s, GSM_SMSMessage * sms);
  * Deletes SMS.
  *
  * \param s State machine pointer.
+ * \param[in] sms SMS structure with SMS location and folder.
  *
  * \return Error code.
  *
@@ -1179,6 +1258,7 @@ GSM_Error GSM_DeleteSMS(GSM_StateMachine * s, GSM_SMSMessage * sms);
  * Sends SMS.
  *
  * \param s State machine pointer.
+ * \param[in] sms SMS structure with SMS data to send.
  *
  * \return Error code.
  *
@@ -1190,6 +1270,8 @@ GSM_Error GSM_SendSMS(GSM_StateMachine * s, GSM_SMSMessage * sms);
  * Sends SMS already saved in phone.
  *
  * \param s State machine pointer.
+ * \param[in] Folder Folder, where message is stored.
+ * \param[in] Location Location, where message is stored.
  *
  * \return Error code.
  *
@@ -1201,39 +1283,44 @@ GSM_Error GSM_SendSavedSMS(GSM_StateMachine * s, int Folder, int Location);
  * Configures fast SMS sending.
  *
  * \param s State machine pointer.
+ * \param[in] enable Whether to enable notifications.
  *
  * \return Error code.
  *
  * \ingroup SMS
  */
-GSM_Error GSM_SetFastSMSSending(GSM_StateMachine * s, bool enable);
+GSM_Error GSM_SetFastSMSSending(GSM_StateMachine * s, gboolean enable);
 
 /**
  * Enable/disable notification on incoming SMS.
  *
  * \param s State machine pointer.
+ * \param[in] enable Whether to enable notifications.
  *
  * \return Error code.
  *
  * \ingroup SMS
  */
-GSM_Error GSM_SetIncomingSMS(GSM_StateMachine * s, bool enable);
+GSM_Error GSM_SetIncomingSMS(GSM_StateMachine * s, gboolean enable);
 
 /**
  * Gets network information from phone.
  *
  * \param s State machine pointer.
+ * \param[in] enable Whether to enable notifications.
  *
  * \return Error code.
  *
  * \ingroup CB
  */
-GSM_Error GSM_SetIncomingCB(GSM_StateMachine * s, bool enable);
+GSM_Error GSM_SetIncomingCB(GSM_StateMachine * s, gboolean enable);
 
 /**
  * Returns SMS folders information.
  *
  * \param s State machine pointer.
+ * \param[out] folders folders Pointer to folders structure, which will be
+ * filled in.
  *
  * \return Error code.
  *
@@ -1245,6 +1332,7 @@ GSM_Error GSM_GetSMSFolders(GSM_StateMachine * s, GSM_SMSFolders * folders);
  * Creates SMS folder.
  *
  * \param s State machine pointer.
+ * \param[in] name Name of SMS folder which should be created.
  *
  * \return Error code.
  *
@@ -1256,6 +1344,7 @@ GSM_Error GSM_AddSMSFolder(GSM_StateMachine * s, unsigned char *name);
  * Deletes SMS folder.
  *
  * \param s State machine pointer.
+ * \param[in] ID ID of SMS folder to delete.
  *
  * \return Error code.
  *
@@ -1267,6 +1356,8 @@ GSM_Error GSM_DeleteSMSFolder(GSM_StateMachine * s, int ID);
  * Lists MMS folders.
  *
  * \param s State machine pointer.
+ * \param folders Pointer to structure, whehe folder information will be
+ * stored.
  *
  * \return Error code.
  *
@@ -1278,23 +1369,29 @@ GSM_Error GSM_GetMMSFolders(GSM_StateMachine * s, GSM_MMSFolders * folders);
  * Retrieves next part of MMS file information.
  *
  * \param s State machine pointer.
+ * \param[in,out] FileID File ID will be stored here, might be
+ * used for consequent reads.
+ * \param[in,out] MMSFolder MMS folder ID will be stored here, might be
+ * used for consequent reads.
+ * \param[in] start Whether to start reading.
  *
  * \return Error code.
  *
  * \ingroup MMS
  */
 GSM_Error GSM_GetNextMMSFileInfo(GSM_StateMachine * s, unsigned char *FileID,
-				 int *MMSFolder, bool start);
+				 int *MMSFolder, gboolean start);
 /**
  * Activates/deactivates noticing about incoming USSDs (UnStructured Supplementary Services).
  *
  * \param s State machine pointer.
+ * \param[in] enable Whether to enable notifications.
  *
  * \return Error code.
  *
  * \ingroup USSD
  */
-GSM_Error GSM_SetIncomingUSSD(GSM_StateMachine * s, bool enable);
+GSM_Error GSM_SetIncomingUSSD(GSM_StateMachine * s, gboolean enable);
 #endif
 
 /* Editor configuration
