@@ -18,6 +18,7 @@
 #include "gsmphones.h"
 #include "gsmstate.h"
 #include "misc/coding/coding.h"
+#include "misc/misc.h"
 #include "device/devfunc.h"
 
 #include "../helper/string.h"
@@ -359,11 +360,13 @@ GSM_Error GSM_RegisterAllPhoneModules(GSM_StateMachine *s)
 		}
 #endif
 
+#ifdef GSM_ENABLE_BACKUP
 		if (s->ConnectionType == GCT_NONE) {
 			smprintf(s,"[Module           - \"%s\"]\n",DUMMYPhone.models);
 			s->Phone.Functions = &DUMMYPhone;
 			return ERR_NONE;
 		}
+#endif
 
 		/* With GNAPgen and auto model we can work with unknown models too */
 #ifdef GSM_ENABLE_GNAPGEN
@@ -435,7 +438,9 @@ GSM_Error GSM_RegisterAllPhoneModules(GSM_StateMachine *s)
 		if (s->Phone.Functions != NULL) return ERR_NONE;
 	}
 #endif
+#ifdef GSM_ENABLE_BACKUP
 	GSM_RegisterModule(s, &DUMMYPhone);
+#endif
 #ifdef GSM_ENABLE_OBEXGEN
 	GSM_RegisterModule(s,&OBEXGENPhone);
 #endif
@@ -553,9 +558,11 @@ GSM_Error GSM_TryGetModel(GSM_StateMachine *s)
 	if (s->Phone.Data.Model[0]==0) {
 		smprintf(s,"[Module           - \"auto\"]\n");
 		switch (s->ConnectionType) {
+#ifdef GSM_ENABLE_BACKUP
 			case GCT_NONE:
 				s->Phone.Functions = &DUMMYPhone;
 				break;
+#endif
 #ifdef GSM_ENABLE_ATGEN
 			case GCT_AT:
 			case GCT_BLUEAT:
@@ -1242,9 +1249,14 @@ GSM_Error GSM_ReadConfig(INI_Section *cfg_info, GSM_Config *cfg, int num)
 
 	/* Set device name */
 	free(cfg->Device);
-	cfg->Device 	 = INI_GetValue(cfg_info, section, "port", 		FALSE);
+	cfg->Device 	 = INI_GetValue(cfg_info, section, "device", 		FALSE);
 	if (!cfg->Device) {
-		cfg->Device		 	 = strdup(DefaultPort);
+		cfg->Device 	 = INI_GetValue(cfg_info, section, "port", 		FALSE);
+		if (!cfg->Device) {
+			cfg->Device		 	 = strdup(DefaultPort);
+		} else {
+			cfg->Device			 = strdup(cfg->Device);
+		}
 	} else {
 		cfg->Device			 = strdup(cfg->Device);
 	}
@@ -1611,7 +1623,10 @@ void GSM_SetSendSMSStatusCallback(GSM_StateMachine *s, SendSMSStatusCallback cal
 
 GSM_StateMachine *GSM_AllocStateMachine(void)
 {
-	return (GSM_StateMachine *)calloc(1, sizeof(GSM_StateMachine));
+	GSM_StateMachine *ret;
+	ret = (GSM_StateMachine *)calloc(1, sizeof(GSM_StateMachine));
+	ret->CurrentConfig = &(ret->Config[0]);
+	return ret;
 }
 
 void GSM_FreeStateMachine(GSM_StateMachine *s)
