@@ -36,7 +36,9 @@ GSM_Error INI_ReadFile(const char *FileName, gboolean Unicode, INI_Section **res
 	*result = NULL;
 
 	f = fopen(FileName,"rb");
-	if (f == NULL) return ERR_CANTOPENFILE;
+	if (f == NULL) {
+		return ERR_CANTOPENFILE;
+	}
 
 	num = 0;
 	while(1) {
@@ -53,12 +55,16 @@ GSM_Error INI_ReadFile(const char *FileName, gboolean Unicode, INI_Section **res
 			}
 			if (Unicode) {
 				if (num == 0) {
-					if (read_buffer_used == read_buffer_pos) continue;
+					if (read_buffer_used == read_buffer_pos) {
+						continue;
+					}
 					ch[0] = read_buffer[read_buffer_pos++];
 					num = 1;
 				}
 				if (num == 1) {
-					if (read_buffer_used == read_buffer_pos) continue;
+					if (read_buffer_used == read_buffer_pos) {
+						continue;
+					}
 					ch[1] = read_buffer[read_buffer_pos++];
 					num = 0;
 				}
@@ -71,7 +77,9 @@ GSM_Error INI_ReadFile(const char *FileName, gboolean Unicode, INI_Section **res
 					ch[2] = ch[0]; ch[0] = ch[1]; ch[1] = ch[2];
 				}
 			} else {
-				if (read_buffer_used == read_buffer_pos) continue;
+				if (read_buffer_used == read_buffer_pos) {
+					continue;
+				}
 				ch[0] = 0;
 				ch[1] = read_buffer[read_buffer_pos++];
 				if (level == -1) level = 0;
@@ -80,7 +88,7 @@ GSM_Error INI_ReadFile(const char *FileName, gboolean Unicode, INI_Section **res
 			    (ch[0] == 0 && ch[1] == 10)) {
 				break;
 			}
-			buffer 			= realloc(buffer,bufferused+2);
+			buffer 			= (unsigned char *)realloc(buffer,bufferused+2);
                         if (buffer == NULL) {
                                 error = ERR_MOREMEMORY;
 				goto done;
@@ -101,20 +109,26 @@ GSM_Error INI_ReadFile(const char *FileName, gboolean Unicode, INI_Section **res
 			ch[1] = buffer[i*2+1];
 			if (level == 0) { /* search for name of section */
 				if (ch[0] == 0 && ch[1] == '[') level = 1;
-				if (ch[0] == 0 && ch[1] == ';') break;
-				if (ch[0] == 0 && ch[1] == '#') break;
+				if (ch[0] == 0 && ch[1] == ';') {
+					break;
+				}
+				if (ch[0] == 0 && ch[1] == '#') {
+					break;
+				}
 				continue;
 			}
 			if (level == 1) { /* section name */
 				if (ch[0] == 0 && ch[1] == ']') {
-					if (buffer1used == 0) break;
+					if (buffer1used == 0) {
+						break;
+					}
 					if (Unicode) {
-						buffer1 		= realloc(buffer1,buffer1used+2);
+						buffer1 		= (unsigned char *)realloc(buffer1,buffer1used+2);
 						buffer1[buffer1used] 	= 0;
 						buffer1[buffer1used+1] 	= 0;
 						buffer1used		= buffer1used + 2;
 					} else {
-						buffer1 		= realloc(buffer1,buffer1used+1);
+						buffer1 		= (unsigned char *)realloc(buffer1,buffer1used+1);
 						buffer1[buffer1used] 	= 0x00;
 						buffer1used		= buffer1used + 1;
 					}
@@ -138,40 +152,54 @@ GSM_Error INI_ReadFile(const char *FileName, gboolean Unicode, INI_Section **res
 					break;
 				}
 				if (Unicode) {
-					buffer1 		= realloc(buffer1,buffer1used+2);
+					buffer1 		= (unsigned char *)realloc(buffer1,buffer1used+2);
 					buffer1[buffer1used] 	= ch[0];
 					buffer1[buffer1used+1] 	= ch[1];
 					buffer1used		= buffer1used + 2;
 				} else {
-					buffer1 		= realloc(buffer1,buffer1used+1);
+					buffer1 		= (unsigned char *)realloc(buffer1,buffer1used+1);
 					buffer1[buffer1used] 	= ch[1];
 					buffer1used		= buffer1used + 1;
 				}
 				continue;
 			}
 			if (level == 2) { /* search for key name */
-				if (ch[0] == 0 && ch[1] == ';') break;
-				if (ch[0] == 0 && ch[1] == '#') break;
+				if (ch[0] == 0 && ch[1] == ';') {
+					break;
+				}
+				if (ch[0] == 0 && ch[1] == '#') {
+					break;
+				}
 				if (ch[0] == 0 && ch[1] == '[') {
 					level = 1;
 					continue;
 				}
 				if (Unicode) {
-			                if (myiswspace(ch)) continue;
+			                if (myiswspace(ch)) {
+						continue;
+					}
 				} else {
-			                if (isspace((int) ch[1])) continue;
+			                if (isspace((int) ch[1])) {
+						continue;
+					}
 				}
 				level = 3;
 			}
 			if (level == 3) { /* key name */
 				if (ch[0] == 0 && ch[1] == '=') {
-					if (buffer1used == 0) break;
+					if (buffer1used == 0) {
+						break;
+					}
 					while(1) {
 						if (Unicode) {
-					                if (!myiswspace(buffer1+(buffer1used-2))) break;
+					                if (!myiswspace(buffer1+(buffer1used-2))) {
+								break;
+							}
 							buffer1used = buffer1used - 2;
 						} else {
-					                if (!isspace((int)buffer1[buffer1used-1])) break;
+					                if (!isspace((int)buffer1[buffer1used-1])) {
+								break;
+							}
 							buffer1used = buffer1used - 1;
 						}
 					}
@@ -179,32 +207,36 @@ GSM_Error INI_ReadFile(const char *FileName, gboolean Unicode, INI_Section **res
 					continue;
 				}
 				if (Unicode) {
-					buffer1 		= realloc(buffer1,buffer1used+2);
+					buffer1 		= (unsigned char *)realloc(buffer1,buffer1used+2);
 					buffer1[buffer1used] 	= ch[0];
 					buffer1[buffer1used+1] 	= ch[1];
 					buffer1used		= buffer1used + 2;
 				} else {
-					buffer1 		= realloc(buffer1,buffer1used+1);
+					buffer1 		= (unsigned char *)realloc(buffer1,buffer1used+1);
 					buffer1[buffer1used] 	= ch[1];
 					buffer1used		= buffer1used + 1;
 				}
 			}
 			if (level == 4) { /* search for key value */
 				if (Unicode) {
-			                if (myiswspace(ch)) continue;
+			                if (myiswspace(ch)) {
+						continue;
+					}
 				} else {
-			                if (isspace((int) ch[1])) continue;
+			                if (isspace((int) ch[1])) {
+						continue;
+					}
 				}
 				level = 5;
 			}
 			if (level == 5) { /* key value */
 				if (Unicode) {
-					buffer2 		= realloc(buffer2,buffer2used+2);
+					buffer2 		= (unsigned char *)realloc(buffer2,buffer2used+2);
 					buffer2[buffer2used] 	= ch[0];
 					buffer2[buffer2used+1] 	= ch[1];
 					buffer2used		= buffer2used + 2;
 				} else {
-					buffer2 		= realloc(buffer2,buffer2used+1);
+					buffer2 		= (unsigned char *)realloc(buffer2,buffer2used+1);
 					buffer2[buffer2used] 	= ch[1];
 					buffer2used		= buffer2used + 1;
 				}
@@ -220,7 +252,9 @@ GSM_Error INI_ReadFile(const char *FileName, gboolean Unicode, INI_Section **res
 					buffer2used -= 1;
 				}
 			}
-			if (buffer2used == 0) continue;
+			if (buffer2used == 0) {
+				continue;
+			}
 
 			entry = (INI_Entry *)malloc(sizeof(*entry));
                         if (entry == NULL) {
@@ -228,19 +262,19 @@ GSM_Error INI_ReadFile(const char *FileName, gboolean Unicode, INI_Section **res
 				goto done;
                         }
 			if (Unicode) {
-				buffer1 		= realloc(buffer1,buffer1used+2);
+				buffer1 		= (unsigned char *)realloc(buffer1,buffer1used+2);
 				buffer1[buffer1used] 	= 0;
 				buffer1[buffer1used+1] 	= 0;
 				buffer1used		= buffer1used + 2;
-				buffer2 		= realloc(buffer2,buffer2used+2);
+				buffer2 		= (unsigned char *)realloc(buffer2,buffer2used+2);
 				buffer2[buffer2used] 	= 0;
 				buffer2[buffer2used+1] 	= 0;
 				buffer2used		= buffer2used + 2;
 			} else {
-				buffer1 		= realloc(buffer1,buffer1used+1);
+				buffer1 		= (unsigned char *)realloc(buffer1,buffer1used+1);
 				buffer1[buffer1used] 	= 0x00;
 				buffer1used		= buffer1used + 1;
-				buffer2 		= realloc(buffer2,buffer2used+1);
+				buffer2 		= (unsigned char *)realloc(buffer2,buffer2used+1);
 				buffer2[buffer2used] 	= 0x00;
 				buffer2used		= buffer2used + 1;
 			}
@@ -261,13 +295,21 @@ GSM_Error INI_ReadFile(const char *FileName, gboolean Unicode, INI_Section **res
 
 			entry->Prev = NULL;
                         entry->Next = INI_info->SubEntries;
-                        if (INI_info->SubEntries != NULL) INI_info->SubEntries->Prev = entry;
+                        if (INI_info->SubEntries != NULL) {
+				INI_info->SubEntries->Prev = entry;
+			}
                         INI_info->SubEntries = entry;
 		}
 	}
 done:
-	free(buffer); free(buffer1); free(buffer2);
+	free(buffer);
+	buffer=NULL;
+	free(buffer1);
+	buffer1=NULL;
+	free(buffer2);
+	buffer2=NULL;
 	fclose(f);
+
 	if (error == ERR_NONE) {
 		*result = INI_head;
 		if (INI_head == NULL) {
@@ -277,7 +319,37 @@ done:
 	return error;
 }
 
-/*
+/**
+ * Returns integer value from configuration.
+ */
+int INI_GetInt(INI_Section *cfg, const unsigned char *section, const unsigned char *key, int fallback)
+{
+	char *str;
+
+	str = (char *)INI_GetValue(cfg, section, key, FALSE);
+	if (str) {
+		return atoi(str);
+	} else {
+		return fallback;
+	}
+}
+
+/**
+ * Returns integer value from configuration.
+ */
+gboolean INI_GetBool(INI_Section *cfg, const unsigned char *section, const unsigned char *key, gboolean fallback)
+{
+	char *str;
+
+	str = (char *)INI_GetValue(cfg, section, key, FALSE);
+	if (str) {
+		return INI_IsTrue(str);
+	} else {
+		return fallback;
+	}
+}
+
+/**
  * Search for key value in file in Windows INI format style
  * Returns found value or NULL
  */
@@ -355,15 +427,18 @@ INI_Entry *INI_FindLastSectionEntry(INI_Section *file_info, const unsigned char
 
 void INI_Free_Entries(INI_Entry *entry)
 {
-	INI_Entry *cur = entry, *next;
+	INI_Entry *cur = entry, *next=NULL;
 
 	if (cur == NULL) return;
 	while (cur != NULL) {
 		next = cur->Next;
 		free(cur->EntryName);
+		cur->EntryName=NULL;
 		free(cur->EntryValue);
+		cur->EntryValue=NULL;
 		free(cur);
-		cur = next;
+		cur=NULL;
+		cur=next;
 	}
 }
 
@@ -375,9 +450,11 @@ void INI_Free(INI_Section *head)
 	while (cur != NULL) {
 		next = cur->Next;
 		free(cur->SectionName);
+		cur->SectionName=NULL;
 		INI_Free_Entries(cur->SubEntries);
 		free(cur);
-		cur = next;
+		cur=NULL;
+		cur=next;
 	}
 }
 
