@@ -14,6 +14,7 @@
 #include <stdio.h>
 #include <stdlib.h>
 #include <sys/timeb.h>
+#include <ctype.h>
 #ifdef WIN32
 #  define WIN32_LEAN_AND_MEAN
 #  include <windows.h>
@@ -236,7 +237,7 @@ char *OSDateTime (GSM_DateTime dt, gboolean TimeZone)
 
 	if (!RecalcDateTime(&timeptr, dt.Year, dt.Month, dt.Day,
 				dt.Hour, dt.Minute, dt.Second)) {
-		retval2[0] = 0;
+		retval2[0] = '\0';
 		return retval2;
 	}
 
@@ -343,7 +344,7 @@ int GetLine(FILE *File, char *Line, int count)
 		num = strlen(Line) - 1;
 		while (num > 0) {
 			if (Line[num] != '\n' && Line[num] != '\r') break;
-			Line[num--] = 0;
+			Line[num--] = '\0';
 		}
 		return strlen(Line);
 	}
@@ -363,63 +364,100 @@ void FreeLines(GSM_CutLines *lines)
 	lines->allocated = 0;
 }
 
-void SplitLines(const char *message, int messagesize, GSM_CutLines *lines, const char *whitespaces, int spaceslen, gboolean eot)
+void SplitLines(const char *message, const int messagesize, GSM_CutLines *lines,
+	const char *whitespaces, const int spaceslen,
+	const char *quotes, const int quoteslen,
+	const gboolean eot)
 {
-	int 	i,number=0,j;
-	gboolean 	whitespace=TRUE, nowwhite;
+	int 	 i=0,number=0,j=0, lastquote = -1;
+	gboolean whitespace = TRUE, nowwhite = FALSE, insidequotes = FALSE;
 
-	for (i = 0; i < lines->allocated; i++)
-		lines->numbers[i]=0;
+	/* Clean current lines */
+	for (i = 0; i < lines->allocated; i++) {
+		lines->numbers[i] = 0;
+	}
 
+	/* Go through message */
 	for (i = 0; i < messagesize; i++) {
 		/* Reallocate buffer if needed */
 		if (number + 1 >= lines->allocated - 1) {
 			lines->allocated += 20;
-			lines->numbers = realloc(lines->numbers, lines->allocated * sizeof(int));
-			if (lines->numbers == NULL) return;
-			for (j = lines->allocated - 20; j < lines->allocated; j++)
+			lines->numbers = (int *)realloc(lines->numbers, lines->allocated * sizeof(int));
+			if (lines->numbers == NULL) {
+				return;
+			}
+			for (j = lines->allocated - 20; j < lines->allocated; j++) {
 				lines->numbers[j] = 0;
+			}
 		}
 
 		nowwhite = FALSE;
+
+		/* Check for quotes */
+		for (j = 0; j < quoteslen; j++) {
+			if (quotes[j] == message[i]) {
+				insidequotes = !(insidequotes);
+				lastquote = i;
+				break;
+			}
+		}
+
+		/* Find matching quote */
+		if (insidequotes) {
+			continue;
+		}
+
+rollback_quote:
+		/* Check for whitespace */
 		for (j = 0; j < spaceslen; j++) {
 			if (whitespaces[j] == message[i]) {
 				nowwhite = TRUE;
 				break;
 			}
 		}
+
+		/* Split line if there is change from whitespace to non whitespace */
 		if (whitespace) {
 			if (!nowwhite) {
-				lines->numbers[number]=i;
+				lines->numbers[number] = i;
 				number++;
-				whitespace=FALSE;
+				whitespace = FALSE;
 			}
 		} else {
 			if (nowwhite) {
-				lines->numbers[number]=i;
+				lines->numbers[number] = i;
 				number++;
-				whitespace=TRUE;
+				whitespace = TRUE;
 			}
 
 		}
 	}
-    	if (eot && !whitespace)
+
+	/* Check for unterminated quotes and roll back to ignore them */
+	if (number % 2 == 1 && insidequotes) {
+		insidequotes = FALSE;
+		i = lastquote;
+		goto rollback_quote;
+	}
+
+	/* Store possible end if there was not just whitespace */
+    	if (eot && !whitespace) {
 		lines->numbers[number] = messagesize;
+	}
 }
 
 const char *GetLineString(const char *message, const GSM_CutLines *lines, int start)
 {
 	static char *retval = NULL;
-	int len;
+	int len=0;
 
 	if (message == NULL) {
 		free(retval);
 		retval = NULL;
 		return NULL;
 	}
-
 	len = GetLineLength(message, lines, start);
-	retval = realloc(retval, len + 1);
+	retval = (char *)realloc(retval, len + 1);
 	if (retval == NULL) {
 		dbgprintf(NULL, "Allocation failed!\n");
 		return NULL;
@@ -427,7 +465,7 @@ const char *GetLineString(const char *message, const GSM_CutLines *lines, int st
 
 	memcpy(retval, message + lines->numbers[start * 2 - 2], len);
 
-	retval[len] = 0;
+	retval[len] = '\0';
 
 	return retval;
 }
@@ -441,7 +479,7 @@ void CopyLineString(char *dest, const char *src, const GSM_CutLines *lines, int
 {
 	int len = GetLineLength(src, lines, start);
 	memcpy(dest, GetLineString(src, lines, start), len);
-	dest[len] = 0;
+	dest[len] = '\0';
 }
 
 const char *GetOS(void)
@@ -616,17 +654,16 @@ gboolean GSM_IsNewerVersion(const char *latest_version, const char *current_vers
 
 void StripSpaces(char *buff)
 {
-	ssize_t i;
+	ssize_t i = 0;
 
-	i = 0;
-	while(iswspace(buff[i])) {
+	while(isspace(buff[i])) {
 		i++;
 	}
 	if (i > 0) {
 		memmove(buff, buff + i, strlen(buff + i));
 	}
 	i = strlen(buff) - 1;
-	while(iswspace(buff[i]) && i >= 0) {
+	while(isspace(buff[i]) && i >= 0) {
 		buff[i] = 0;
 		i--;
 	}
