@@ -446,6 +446,37 @@ GSM_Error SAMSUNG_SetRingtone(GSM_StateMachine *s, GSM_Ringtone *Ringtone, int *
 		Ringtone->BinaryTone.Length, ID_SetRingtone);
 }
 
+/**
+ * Check what variant of calendar protocol for Samsung is supported.
+ */
+GSM_Error SAMSUNG_CheckCalendar(GSM_StateMachine *s)
+{
+ 	GSM_Phone_ATGENData *Priv = &s->Phone.Data.Priv.ATGEN;
+	GSM_Error error;
+
+	if (Priv->SamsungCalendar != 0) {
+		return ERR_NONE;
+	}
+
+	smprintf(s, "Checking for supported calendar commands\n");
+
+	ATGEN_WaitForAutoLen(s, "AT+ORGI?\r", 0x00, 10, ID_GetProtocol);
+	if (error == ERR_NONE) {
+		Priv->SamsungCalendar = SAMSUNG_ORG;
+		return ERR_NONE;
+	}
+
+	ATGEN_WaitForAutoLen(s, "AT+SSHT?\r", 0x00, 10, ID_GetProtocol);
+	if (error == ERR_NONE) {
+		Priv->SamsungCalendar = SAMSUNG_SSH;
+		return ERR_NONE;
+	}
+
+	Priv->SamsungCalendar = SAMSUNG_NONE;
+	return ERR_NONE;
+
+}
+
 GSM_Error SAMSUNG_ReplyGetMemoryInfo(GSM_Protocol_Message msg, GSM_StateMachine *s)
 {
  	GSM_Phone_ATGENData 	*Priv = &s->Phone.Data.Priv.ATGEN;
@@ -610,12 +641,22 @@ GSM_Error SAMSUNG_ReplyGetMemory(GSM_Protocol_Message msg, GSM_StateMachine *s)
 
 GSM_Error SAMSUNG_SetMemory(GSM_StateMachine *s, GSM_MemoryEntry *entry)
 {
+ 	GSM_Phone_ATGENData *Priv = &s->Phone.Data.Priv.ATGEN;
+
+	SAMSUNG_CheckCalendar(s);
+
+	if (Priv->SamsungCalendar == SAMSUNG_NONE) {
+		return ERR_NOTSUPPORTED;
+	} else if (Priv->SamsungCalendar == SAMSUNG_SSH) {
+		return ERR_NOTIMPLEMENTED;
+	}
+
 	/* FIXME: Here you have to implement conversion of GSM_MemoryEntry to AT command */
 	smprintf(s, "Setting memory for Samsung not implemented yet!\n");
 	return ERR_NOTIMPLEMENTED;
 }
 
-GSM_Error SAMSUNG_ReplyGetCalendarStatus(GSM_Protocol_Message msg, GSM_StateMachine *s)
+GSM_Error SAMSUNG_ORG_ReplyGetCalendarStatus(GSM_Protocol_Message msg, GSM_StateMachine *s)
 {
 	GSM_Phone_ATGENData	*Priv = &s->Phone.Data.Priv.ATGEN;
 	GSM_Error error;
@@ -647,15 +688,56 @@ GSM_Error SAMSUNG_ReplyGetCalendarStatus(GSM_Protocol_Message msg, GSM_StateMach
 	return ERR_NONE;
 }
 
+GSM_Error SAMSUNG_SSH_ReplyGetCalendarStatus(GSM_Protocol_Message msg, GSM_StateMachine *s)
+{
+	GSM_Phone_ATGENData	*Priv = &s->Phone.Data.Priv.ATGEN;
+	GSM_Error error;
+	int ignore;
+
+	if (Priv->ReplyState != AT_Reply_OK) {
+		switch (s->Phone.Data.Priv.ATGEN.ReplyState) {
+		case AT_Reply_Error:
+			return ERR_NOTSUPPORTED;
+		case AT_Reply_CMSError:
+			return ATGEN_HandleCMSError(s);
+		case AT_Reply_CMEError:
+			return ATGEN_HandleCMEError(s);
+		default:
+			return ERR_UNKNOWNRESPONSE;
+		}
+	}
+
+	error = ATGEN_ParseReply(s,
+		GetLineString(msg.Buffer, &Priv->Lines, 2),
+		"+SSHI: @i, @i, @i",
+		&s->Phone.Data.CalStatus->Used,
+		&s->Phone.Data.CalStatus->Free,
+		&ignore);
+	if (error != ERR_NONE) return error;
+	s->Phone.Data.CalStatus->Free -= s->Phone.Data.CalStatus->Used;
+	return ERR_NONE;
+}
+
 GSM_Error SAMSUNG_GetCalendarStatus(GSM_StateMachine *s, GSM_CalendarStatus *Status)
 {
 	GSM_Error error;
+ 	GSM_Phone_ATGENData *Priv = &s->Phone.Data.Priv.ATGEN;
 
 	s->Phone.Data.CalStatus = Status;
 
-	ATGEN_WaitForAutoLen(s, "AT+ORGI?\r", 0x00, 10, ID_GetCalendarNotesInfo);
+	SAMSUNG_CheckCalendar(s);
 
-	return error;
+	if (Priv->SamsungCalendar == SAMSUNG_NONE) {
+		return ERR_NOTSUPPORTED;
+	} else if (Priv->SamsungCalendar == SAMSUNG_SSH) {
+		ATGEN_WaitForAutoLen(s, "AT+SSHI?\r", 0x00, 10, ID_GetCalendarNotesInfo);
+		return error;
+	} else if (Priv->SamsungCalendar == SAMSUNG_ORG) {
+		ATGEN_WaitForAutoLen(s, "AT+ORGI?\r", 0x00, 10, ID_GetCalendarNotesInfo);
+		return error;
+	}
+
+	return ERR_BUG;
 }
 
 GSM_Error SAMSUNG_ParseAppointment(GSM_StateMachine *s, const char *line)
@@ -861,7 +943,7 @@ par24: Empty
 	return ERR_NONE;
 }
 
-GSM_Error SAMSUNG_ReplyGetCalendar(GSM_Protocol_Message msg, GSM_StateMachine *s)
+GSM_Error SAMSUNG_ORG_ReplyGetCalendar(GSM_Protocol_Message msg, GSM_StateMachine *s)
 {
 	GSM_Phone_ATGENData	*Priv = &s->Phone.Data.Priv.ATGEN;
 	GSM_Error error;
@@ -915,10 +997,22 @@ GSM_Error SAMSUNG_ReplyGetCalendar(GSM_Protocol_Message msg, GSM_StateMachine *s
 	}
 }
 
+GSM_Error SAMSUNG_SSH_ReplyGetCalendar(GSM_Protocol_Message msg, GSM_StateMachine *s)
+{
+	return ERR_NOTIMPLEMENTED;
+}
+
 GSM_Error SAMSUNG_GetNextCalendar(GSM_StateMachine *s, GSM_CalendarEntry *Note, gboolean start)
 {
 	GSM_Error error;
-	GSM_Phone_ATGENData	*Priv = &s->Phone.Data.Priv.ATGEN;
+ 	GSM_Phone_ATGENData *Priv = &s->Phone.Data.Priv.ATGEN;
+
+	SAMSUNG_CheckCalendar(s);
+
+	if (Priv->SamsungCalendar == SAMSUNG_NONE) {
+		return ERR_NOTSUPPORTED;
+	}
+
 	if (start) {
 		/* One bellow actual first position */
 		Note->Location = 0;
@@ -955,16 +1049,27 @@ GSM_Error SAMSUNG_GetCalendar(GSM_StateMachine *s, GSM_CalendarEntry *Note)
 	char req[50];
 	GSM_Error error;
 	size_t len;
+ 	GSM_Phone_ATGENData *Priv = &s->Phone.Data.Priv.ATGEN;
 
 	s->Phone.Data.Cal = Note;
 
-	len = sprintf(req, "AT+ORGR=%d\r", Note->Location - 1);
+	SAMSUNG_CheckCalendar(s);
+
+	if (Priv->SamsungCalendar == SAMSUNG_NONE) {
+		return ERR_NOTSUPPORTED;
+	} else if (Priv->SamsungCalendar == SAMSUNG_ORG) {
+		len = sprintf(req, "AT+ORGR=%d\r", Note->Location - 1);
+	} else if (Priv->SamsungCalendar == SAMSUNG_SSH) {
+		len = sprintf(req, "AT+SSHR=%d\r", Note->Location);
+	} else {
+		return ERR_BUG;
+	}
 
 	ATGEN_WaitFor(s, req, len, 0x00, 10, ID_GetCalendarNote);
 	return error;
 }
 
-GSM_Error SAMSUNG_ReplySetCalendar(GSM_Protocol_Message msg, GSM_StateMachine *s)
+GSM_Error SAMSUNG_ORG_ReplySetCalendar(GSM_Protocol_Message msg, GSM_StateMachine *s)
 {
 	return ERR_NOTIMPLEMENTED;
 }
@@ -974,8 +1079,19 @@ GSM_Error SAMSUNG_DelCalendar(GSM_StateMachine *s, GSM_CalendarEntry *Note)
 	char req[50];
 	GSM_Error error;
 	size_t len;
+ 	GSM_Phone_ATGENData *Priv = &s->Phone.Data.Priv.ATGEN;
 
-	len = sprintf(req, "AT+ORGD=%d\r", Note->Location);
+	SAMSUNG_CheckCalendar(s);
+
+	if (Priv->SamsungCalendar == SAMSUNG_NONE) {
+		return ERR_NOTSUPPORTED;
+	} else if (Priv->SamsungCalendar == SAMSUNG_ORG) {
+		len = sprintf(req, "AT+ORGD=%d\r", Note->Location - 1);
+	} else if (Priv->SamsungCalendar == SAMSUNG_SSH) {
+		len = sprintf(req, "AT+SSHD=%d\r", Note->Location);
+	} else {
+		return ERR_BUG;
+	}
 
 	ATGEN_WaitFor(s, req, len, 0x00, 10, ID_DeleteCalendarNote);
 	return error;
@@ -983,12 +1099,32 @@ GSM_Error SAMSUNG_DelCalendar(GSM_StateMachine *s, GSM_CalendarEntry *Note)
 
 GSM_Error SAMSUNG_SetCalendar(GSM_StateMachine *s, GSM_CalendarEntry *Note)
 {
-	return ERR_NOTIMPLEMENTED;
+ 	GSM_Phone_ATGENData *Priv = &s->Phone.Data.Priv.ATGEN;
+
+	SAMSUNG_CheckCalendar(s);
+
+	if (Priv->SamsungCalendar == SAMSUNG_NONE) {
+		return ERR_NOTSUPPORTED;
+	} else if (Priv->SamsungCalendar == SAMSUNG_ORG) {
+		return ERR_NOTIMPLEMENTED;
+	} else {
+		return ERR_NOTIMPLEMENTED;
+	}
 }
 
 GSM_Error SAMSUNG_AddCalendar(GSM_StateMachine *s, GSM_CalendarEntry *Note)
 {
-	return ERR_NOTIMPLEMENTED;
+ 	GSM_Phone_ATGENData *Priv = &s->Phone.Data.Priv.ATGEN;
+
+	SAMSUNG_CheckCalendar(s);
+
+	if (Priv->SamsungCalendar == SAMSUNG_NONE) {
+		return ERR_NOTSUPPORTED;
+	} else if (Priv->SamsungCalendar == SAMSUNG_ORG) {
+		return ERR_NOTIMPLEMENTED;
+	} else {
+		return ERR_NOTIMPLEMENTED;
+	}
 }
 #endif
 
