@@ -484,6 +484,10 @@ static GSM_Error N6510_SearchForFileName1(GSM_StateMachine *s, GSM_File *File)
 	memcpy(BackupCache, Priv->FilesCache, sizeof(GSM_File) * Priv->FilesLocationsUsed);
 	FilesLocationsUsed = Priv->FilesLocationsUsed;
 
+	/* Allocate new cache */
+	error = N6510_AllocFileCache(s, 1);
+	if (error != ERR_NONE) return error;
+
 	/* putting own data */
 	Priv->FilesCache[0].Level    	= 1;
 	Priv->FilesLocationsUsed 	= 1;
@@ -1113,7 +1117,7 @@ static GSM_Error N6510_PrivGetFolderListing2(GSM_StateMachine *s, GSM_File *File
 
 	while (!Priv->FilesEnd) {
 		usleep(1000);
-		if (GSM_ReadDevice(s,TRUE)==0) {
+		if (GSM_ReadDevice(s,TRUE) <= 0) {
 			i++;
 		} else {
 			i=0;
@@ -2212,6 +2216,8 @@ GSM_Error N6510_PrivGetFilesystemSMSFolders(GSM_StateMachine *s, GSM_SMSFolders
 
 		Start = FALSE;
 
+		smprintf(s, "Folder name: '%s'\n", DecodeUnicodeString(Files.Name));
+
 		if (!strcmp(DecodeUnicodeString(Files.Name),"exchange")) {
 			continue;
 		} else if (!strcmp(DecodeUnicodeString(Files.Name),"predefdrafts")) {
@@ -2253,6 +2259,12 @@ GSM_Error N6510_PrivGetFilesystemSMSFolders(GSM_StateMachine *s, GSM_SMSFolders
 			}
 		}
 		folders->Folder[folders->Number].Memory      = MEM_ME;
+		smprintf(s, "Folder[%d] = \"%s\", memory: %s, inbox: %d, outbox: %d\n",
+			folders->Number,
+			DecodeUnicodeString(folders->Folder[folders->Number].Name),
+			GSM_MemoryTypeToString(folders->Folder[folders->Number].Memory),
+			folders->Folder[folders->Number].InboxFolder,
+			folders->Folder[folders->Number].OutboxFolder);
 		folders->Number++;
 	}
 }
@@ -2312,7 +2324,7 @@ GSM_Error N6510_DecodeFilesystemSMS(GSM_StateMachine *s, GSM_MultiSMSMessage *sm
 	has_number = FALSE;
 
 	/* Do we have any PDU data? */
-	if (FFF->Buffer[7] > 0) {
+	if (FFF->Buffer[7] > 0 && FFF->Used > 176) {
 		/* Parse PDU data */
 		error = GSM_DecodePDUFrame(&(s->di), &(sms->SMS[0]),  FFF->Buffer + 176, FFF->Used - 176, &parse_len, FALSE);
 		if (error != ERR_NONE) return error;
@@ -2344,7 +2356,10 @@ GSM_Error N6510_DecodeFilesystemSMS(GSM_StateMachine *s, GSM_MultiSMSMessage *sm
 	/* Process structured data */
 	pos = 176 + FFF->Buffer[7];
 
-	if (pos >= FFF->Used) return ERR_NONE;
+	/* No structured data? */
+	if (pos >= FFF->Used) {
+		goto done;
+	}
 
 	/* First master block - 0x01 <WORD LENGTH> */
 	if (FFF->Buffer[pos] != 0x01) {
@@ -2396,7 +2411,11 @@ GSM_Error N6510_DecodeFilesystemSMS(GSM_StateMachine *s, GSM_MultiSMSMessage *sm
 						CopyUnicodeString(sms->SMS[0].Number, FFF->Buffer + pos + 3);
 						has_number = TRUE;
 					} else {
-						CopyUnicodeString(sms->SMS[0].OtherNumbers[sms->SMS[0].OtherNumbersNum++], FFF->Buffer + pos + 3);
+						if (sms->SMS[0].OtherNumbersNum < GSM_SMS_OTHER_NUMBERS) {
+							CopyUnicodeString(sms->SMS[0].OtherNumbers[sms->SMS[0].OtherNumbersNum++], FFF->Buffer + pos + 3);
+						} else {
+							smprintf(s, "WARNING: Too many recipients, ignoring some!\n");
+						}
 					}
 				}
 				break;
@@ -2416,7 +2435,9 @@ GSM_Error N6510_DecodeFilesystemSMS(GSM_StateMachine *s, GSM_MultiSMSMessage *sm
 				break;
 			case 0x24:
 				/* 24$|00 |01 |01 */
-				if (FFF->Buffer[pos + 2] != 1 || FFF->Buffer[pos + 3] != 1) {
+				/* 24$|00 |01 |00 */
+				if ((FFF->Buffer[pos + 2] != 1 || FFF->Buffer[pos + 3] != 1) &&
+					(FFF->Buffer[pos + 2] != 1 || FFF->Buffer[pos + 3] != 0)) {
 					unknown = TRUE;
 				}
 				break;
@@ -2472,6 +2493,7 @@ GSM_Error N6510_DecodeFilesystemSMS(GSM_StateMachine *s, GSM_MultiSMSMessage *sm
 		pos += 3 + (FFF->Buffer[pos + 1] << 8) + FFF->Buffer[pos + 2];
 	}
 
+done:
 	sms->SMS[0].DateTime = FFF->Modified;
 	sms->SMS[0].DateTime.Timezone = 0;
 
@@ -2481,6 +2503,8 @@ GSM_Error N6510_DecodeFilesystemSMS(GSM_StateMachine *s, GSM_MultiSMSMessage *sm
 	N26510_SetSMSLocation(s, &sms->SMS[0], 0, location);
 
 	sms->SMS[0].Folder = Priv->SMSFileFolder;
+	smprintf(s, "Folder[%d] %s: %d\n", sms->SMS[0].Folder, DecodeUnicodeString(Priv->LastSMSFolders.Folder[sms->SMS[0].Folder].Name), Priv->LastSMSFolders.Folder[sms->SMS[0].Folder].InboxFolder);
+	sms->SMS[0].InboxFolder = Priv->LastSMSFolders.Folder[sms->SMS[0].Folder].InboxFolder;
 	sms->SMS[0].Location = 0; /* fixme */
 
 	return ERR_NONE;
@@ -2516,7 +2540,7 @@ GSM_Error N6510_GetNextFilesystemSMS(GSM_StateMachine *s, GSM_MultiSMSMessage *s
 		while (Priv->SMSFileError == ERR_EMPTY) {
 			Priv->SMSFileFolder++;
 			/* Too high folder number */
-			if ((Priv->SMSFileFolder-1) >= Priv->LastSMSFolders.Number) {
+			if (Priv->SMSFileFolder > Priv->LastSMSFolders.Number) {
 				return ERR_EMPTY;
 			}
 
