@@ -992,6 +992,18 @@ void NOKIA_DecodeDateTime(GSM_StateMachine *s, unsigned char* buffer, GSM_DateTi
 		datetime->Year, datetime->Month, datetime->Day);
 }
 
+void NOKIA_EncodeDateTime(GSM_StateMachine *s UNUSED, unsigned char* buffer, GSM_DateTime *datetime)
+{
+	buffer[0] = datetime->Year / 256;
+	buffer[1] = datetime->Year % 256;
+	buffer[2] = datetime->Month;
+	buffer[3] = datetime->Day;
+
+	buffer[4] = datetime->Hour;
+	buffer[5] = datetime->Minute;
+}
+
+
 #if defined(GSM_ENABLE_NOKIA_DCT3) || defined(GSM_ENABLE_NOKIA_DCT4)
 
 /* --------------------- Some general Nokia functions ---------------------- */
@@ -1003,7 +1015,10 @@ void NOKIA_DecodeSMSState(GSM_StateMachine *s, unsigned char state, GSM_SMSMessa
 		case 0x03 : sms->State = SMS_UnRead; break;
 		case 0x05 : sms->State = SMS_Sent;   break;
 		case 0x07 : sms->State = SMS_UnSent; break;
-		default	  : smprintf(s, "Unknown SMS state: %02x\n",state);
+		default	  :
+			sms->State = SMS_Read;
+			smprintf(s, "Unknown SMS state: %02x\n",state);
+			break;
 	}
 }
 
@@ -1085,17 +1100,6 @@ GSM_MemoryType NOKIA_GetMemoryType(GSM_StateMachine *s UNUSED, GSM_MemoryType me
 	return 0xff;
 }
 
-void NOKIA_EncodeDateTime(GSM_StateMachine *s UNUSED, unsigned char* buffer, GSM_DateTime *datetime)
-{
-	buffer[0] = datetime->Year / 256;
-	buffer[1] = datetime->Year % 256;
-	buffer[2] = datetime->Month;
-	buffer[3] = datetime->Day;
-
-	buffer[4] = datetime->Hour;
-	buffer[5] = datetime->Minute;
-}
-
 void NOKIA_SortSMSFolderStatus(GSM_StateMachine *s, GSM_NOKIASMSFolder *Folder)
 {
 	int i,j;
@@ -2643,6 +2647,8 @@ GSM_Error N71_65_EnableFunctions(GSM_StateMachine *s,const char *buff,int len)
 GSM_Error N71_65_ReplySendDTMF(GSM_Protocol_Message msg, GSM_StateMachine *s)
 {
 	switch (msg.Buffer[3]) {
+	case 0xf0:
+		return ERR_NOTSUPPORTED;
 	case 0x51:
 		smprintf(s, "DTMF sent OK\n");
 		return ERR_NONE;
