@@ -75,8 +75,11 @@ static GSM_Error ALCABUS_WriteMessage (GSM_StateMachine *s, unsigned const char
 
 	GSM_DumpMessageLevel2(s, buffer, size, type);
 	GSM_DumpMessageLevel3(s, buffer, size, type);
+
 	while (sent != size ) {
-		if ((i = s->Device.Functions->WriteDevice(s,buffer + sent, size - sent)) == 0) {
+		i = s->Device.Functions->WriteDevice(s,buffer + sent, size - sent);
+
+		if (!i) {
 			return ERR_DEVICEWRITEERROR;
 		}
 		sent += i;
@@ -87,8 +90,10 @@ static GSM_Error ALCABUS_WriteMessage (GSM_StateMachine *s, unsigned const char
 		while (d->busy) {
 			GSM_ReadDevice(s,TRUE);
 			usleep(1000);
-			i++;
-			if (i == 10) return ERR_TIMEOUT;
+
+			if (++i == 10) {
+				return ERR_TIMEOUT;
+			}
 		}
 	}
 	return ERR_NONE;
