@@ -41,7 +41,10 @@ GSM_Error SaveICS(char *FileName, GSM_Backup *backup)
 		chk_fwrite(Buffer,1,2,file);
 		Length = 0;
 		error = GSM_EncodeVCALENDAR(Buffer, sizeof(Buffer),&Length,backup->Calendar[i],FALSE,Mozilla_iCalendar);
-		if (error != ERR_NONE) return error;
+		if (error != ERR_NONE) {
+			fclose(file);
+			return error;
+		}
 		chk_fwrite(Buffer,1,Length,file);
 		i++;
 	}
@@ -51,7 +54,10 @@ GSM_Error SaveICS(char *FileName, GSM_Backup *backup)
 		chk_fwrite(Buffer,1,2,file);
 		Length = 0;
 		error = GSM_EncodeVTODO(Buffer, sizeof(Buffer), &Length,backup->ToDo[i],FALSE,Mozilla_VToDo);
-		if (error != ERR_NONE) return error;
+		if (error != ERR_NONE) {
+			fclose(file);
+			return error;
+		}
 		chk_fwrite(Buffer,1,Length,file);
 		i++;
 	}
