@@ -223,7 +223,7 @@ void GSM_GetCalendarRecurranceRepeat(GSM_Debug_Info *di, unsigned char *rec, uns
 
 gboolean GSM_IsCalendarNoteFromThePast(GSM_CalendarEntry *note)
 {
-	gboolean 		Past = TRUE;
+	gboolean 		Past = TRUE, Repeating = FALSE, RepeatingEnd = FALSE;
 	int		i,End=-1;
 	GSM_DateTime	DT;
 	char		rec[20],endday[20];
@@ -240,7 +240,17 @@ gboolean GSM_IsCalendarNoteFromThePast(GSM_CalendarEntry *note)
 			    note->Entries[i].Date.Day >= DT.Day) Past = FALSE;
 			break;
 		case CAL_REPEAT_STOPDATE:
-			if (End == -1) End = i;
+			End = i;
+			RepeatingEnd = TRUE;
+			break;
+		case CAL_REPEAT_DAYOFWEEK:
+		case CAL_REPEAT_DAY:
+		case CAL_REPEAT_DAYOFYEAR:
+		case CAL_REPEAT_WEEKOFMONTH:
+		case CAL_REPEAT_MONTH:
+		case CAL_REPEAT_FREQUENCY:
+			Repeating = TRUE;
+			break;
 		default:
 			break;
 		}
@@ -260,6 +270,9 @@ gboolean GSM_IsCalendarNoteFromThePast(GSM_CalendarEntry *note)
 			    note->Entries[End].Date.Day >= DT.Day) Past = FALSE;
 		}
 	}
+	if (Repeating && ! RepeatingEnd) {
+		return FALSE;
+	}
 	return Past;
 }
 
@@ -371,12 +384,19 @@ GSM_Error GSM_Translate_Category (GSM_CatTranslation direction, char *string, GS
 		else if (strstr(string,"SPECIAL OCCASION")) 	*Type = GSM_CAL_BIRTHDAY;
 		else if (strstr(string,"ANNIVERSARY")) 		*Type = GSM_CAL_BIRTHDAY;
 		else if (strstr(string,"APPOINTMENT")) 		*Type = GSM_CAL_MEETING;
-		/* These are the Nokia 6230i categories in german. */
+		else if (strstr(string,"SHOPPING LIST")) 	*Type = GSM_CAL_SHOPPING;
+		/* These are the Nokia 6230i categories in local language. */
 		else if (strstr(string,"Erinnerung"))	 	*Type = GSM_CAL_REMINDER;
 		else if (strstr(string,"Besprechung"))	 	*Type = GSM_CAL_MEETING;
 		else if (strstr(string,"Anrufen"))	 	*Type = GSM_CAL_CALL;
 		else if (strstr(string,"Geburtstag"))	 	*Type = GSM_CAL_BIRTHDAY;
 		else if (strstr(string,"Notiz"))	 	*Type = GSM_CAL_MEMO;
+
+		else if (strstr(string,"Reminder"))	 	*Type = GSM_CAL_REMINDER;
+		else if (strstr(string,"Meeting"))	 	*Type = GSM_CAL_MEETING;
+		else if (strstr(string,"Call"))		 	*Type = GSM_CAL_CALL;
+		else if (strstr(string,"Birthday"))	 	*Type = GSM_CAL_BIRTHDAY;
+		else if (strstr(string,"Memo"))		 	*Type = GSM_CAL_MEMO;
 		/* default */
 		else *Type = GSM_CAL_MEETING;
 		break;
@@ -401,6 +421,9 @@ GSM_Error GSM_Translate_Category (GSM_CatTranslation direction, char *string, GS
 			case GSM_CAL_BIRTHDAY:
 				strcpy(string, "ANNIVERSARY");
 				break;
+			case GSM_CAL_SHOPPING:
+				strcpy(string, "SHOPPING LIST");
+				break;
 			case GSM_CAL_MEMO:
 			default:
 				strcpy(string, "MISCELLANEOUS");
@@ -791,6 +814,7 @@ void GSM_ToDo_AdjustDate(GSM_ToDoEntry *note, GSM_DeltaTime *delta)
 			case TODO_SILENT_ALARM_DATETIME:
 			case TODO_LAST_MODIFIED:
 			case TODO_START_DATETIME:
+			case TODO_COMPLETED_DATETIME:
 				note->Entries[i].Date = GSM_AddTime(note->Entries[i].Date, *delta);
 				break;
 			case TODO_TEXT:
@@ -1131,6 +1155,10 @@ GSM_Error GSM_EncodeVTODO(char *Buffer, const size_t buff_len, size_t *Length, G
 				error = VC_StoreDateTime(Buffer, buff_len, Length, &note->Entries[i].Date, "DTSTART");
 				if (error != ERR_NONE) return error;
 				break;
+			case TODO_COMPLETED_DATETIME:
+				error = VC_StoreDateTime(Buffer, buff_len, Length, &note->Entries[i].Date, "COMPLETED");
+				if (error != ERR_NONE) return error;
+				break;
 			case TODO_LAST_MODIFIED:
 				error = VC_StoreDateTime(Buffer, buff_len, Length, &note->Entries[i].Date, "LAST-MODIFIED");
 				if (error != ERR_NONE) return error;
@@ -1967,6 +1995,11 @@ GSM_Error GSM_DecodeVCALENDAR_VTODO(GSM_Debug_Info *di, char *Buffer, size_t *Po
 					ToDo->EntriesNum++;
 				}
 			}
+			if (ReadVCALDate(Line, "COMLETED", &Date, &is_date_only)) {
+				ToDo->Entries[ToDo->EntriesNum].Date = Date;
+				ToDo->Entries[ToDo->EntriesNum].EntryType = TODO_COMPLETED_DATETIME;
+				ToDo->EntriesNum++;
+			}
 			if (ReadVCALDate(Line, "DTSTART", &Date, &is_date_only)) {
 				ToDo->Entries[ToDo->EntriesNum].Date = Date;
 				ToDo->Entries[ToDo->EntriesNum].EntryType = TODO_START_DATETIME;
@@ -2019,6 +2052,11 @@ GSM_Error GSM_DecodeVCALENDAR_VTODO(GSM_Debug_Info *di, char *Buffer, size_t *Po
 				ToDo->Entries[ToDo->EntriesNum].Number	  = 1;
 				ToDo->EntriesNum++;
 			}
+			if (strstr(Line,"STATUS:NEEDS ACTION")) {
+				ToDo->Entries[ToDo->EntriesNum].EntryType = TODO_COMPLETED;
+				ToDo->Entries[ToDo->EntriesNum].Number	  = 0;
+				ToDo->EntriesNum++;
+			}
 			if ((ReadVCALText(Line, "X-IRMC-LUID", Buff, ToDoVer == Mozilla_VToDo))) {
 				ToDo->Entries[ToDo->EntriesNum].EntryType = TODO_LUID;
 				CopyUnicodeString(ToDo->Entries[ToDo->EntriesNum].Text,
