@@ -329,40 +329,103 @@ void GSM_EncodeMMSIndicatorSMSText(unsigned char *Buffer, size_t *Length, GSM_MM
 	unsigned char 	buffer[200];
 	int		i;
 
-	strcpy(Buffer+(*Length),"\xE6\x06\"");
-	(*Length)=(*Length)+3;
+
+	/*
+	 * WSP header
+	 */
+
+	/* Transaction ID (maybe this should be random?) */
+	Buffer[(*Length)++] = 0xe6;
+	/* PDU type push */
+	Buffer[(*Length)++] = 0x06;
+	/* Header length */
+	Buffer[(*Length)++] = 0x22;
+	/* MIME type (header) */
 	strcpy(Buffer+(*Length),"application/vnd.wap.mms-message");
 	(*Length)=(*Length)+31;
 	Buffer[(*Length)++] = 0x00;
 
-	strcpy(Buffer+(*Length),"\xAF\x84\x8C\x82\x98");
-	(*Length)=(*Length)+5;
+	/* WAP push (x-wap-application.ua) */
+	Buffer[(*Length)++] = 0xaf;
+	Buffer[(*Length)++] = 0x84;
 
+	/*
+	 * MMS data
+	 */
+
+	/* Transaction type */
+	Buffer[(*Length)++] = 0x8c;
+	/* m-notification-ind */
+	Buffer[(*Length)++] = 0x82;
+
+	/* Transaction ID, usually last part of address */
+	Buffer[(*Length)++] = 0x98;
 	i = strlen(Indicator.Address);
 	while (Indicator.Address[i] != '/' && i!=0) i--;
 	strcpy(Buffer+(*Length),Indicator.Address+i+1);
 	(*Length)=(*Length)+strlen(Indicator.Address+i+1);
 	Buffer[(*Length)++] = 0x00;
 
-	strcpy(Buffer+(*Length),"\x8D\x90\x89");
-	(*Length)=(*Length)+3;
+	/* MMS version */
+	Buffer[(*Length)++] = 0x8d;
+	/* 1.2 (0x90 is 1.0) */
+	Buffer[(*Length)++] = 0x92;
 
+	/* Message class */
+	switch (Indicator.Class) {
+		case GSM_MMS_None:
+			break;
+		case GSM_MMS_Personal:
+			Buffer[(*Length)++] = 0x8a;
+			Buffer[(*Length)++] = 0x80;
+			break;
+		case GSM_MMS_Advertisement:
+			Buffer[(*Length)++] = 0x8a;
+			Buffer[(*Length)++] = 0x81;
+			break;
+		case GSM_MMS_Info:
+			Buffer[(*Length)++] = 0x8a;
+			Buffer[(*Length)++] = 0x82;
+			break;
+		case GSM_MMS_Auto:
+			Buffer[(*Length)++] = 0x8a;
+			Buffer[(*Length)++] = 0x83;
+			break;
+	}
+
+	if (Indicator.MessageSize > 0) {
+		/* Message size */
+		Buffer[(*Length)++] = 0x8e;
+		/* Length of size */
+		Buffer[(*Length)++] = 0x04;
+		Buffer[(*Length)++] = ((long)Indicator.MessageSize >> 24) & 0xff;
+		Buffer[(*Length)++] = ((long)Indicator.MessageSize >> 16) & 0xff;
+		Buffer[(*Length)++] = ((long)Indicator.MessageSize >>  8) & 0xff;
+		Buffer[(*Length)++] = ((long)Indicator.MessageSize >>  0) & 0xff;
+	}
+
+	/* Sender address */
+	Buffer[(*Length)++] = 0x89;
 	sprintf(buffer,"%s/TYPE=PLMN",Indicator.Sender);
-	Buffer[(*Length)++] = strlen(buffer);
+	/* Field size */
+	Buffer[(*Length)++] = strlen(buffer) + 2;
+	/* Sender address is present */
 	Buffer[(*Length)++] = 0x80;
 	strcpy(Buffer+(*Length),buffer);
 	(*Length)=(*Length)+strlen(buffer);
+	/* Zero terminate */
 	Buffer[(*Length)++] = 0x00;
 
+	/* Subject */
 	Buffer[(*Length)++] = 0x96;
 	strcpy(Buffer+(*Length),Indicator.Title);
 	(*Length)=(*Length)+strlen(Indicator.Title);
 	Buffer[(*Length)++] = 0x00;
 
-	strcpy(Buffer+(*Length),"\x8A\x80\x8E\x02\x47\xBB\x88\x05\x81\x03\x02\xA3");
-	(*Length)=(*Length)+12;
-	Buffer[(*Length)++] = 0x00;
+	strcpy(Buffer+(*Length),"\x88\x05\x81\x03\x02\xA3\xA3");
+	(*Length)=(*Length)+7;
 
+	/* Content location */
 	Buffer[(*Length)++] = 0x83;
 	strcpy(Buffer+(*Length),Indicator.Address);
 	(*Length)=(*Length)+strlen(Indicator.Address);
@@ -374,12 +437,17 @@ GSM_Error GSM_ClearMMSMultiPart(GSM_EncodedMultiPartMMSInfo *info)
 	int i;
 
 	for (i=0;i<GSM_MAX_MULTI_MMS;i++) {
-		if (info->Entries[i].File.Buffer != NULL) free(info->Entries[i].File.Buffer);
+		if (info->Entries[i].File.Buffer != NULL) {
+			free(info->Entries[i].File.Buffer);
+			info->Entries[i].File.Buffer=NULL;
+		}
 	}
 
 	memset(info,0,sizeof(GSM_EncodedMultiPartMMSInfo));
 
-	for (i=0;i<GSM_MAX_MULTI_MMS;i++) info->Entries[i].File.Buffer = NULL;
+	for (i=0;i<GSM_MAX_MULTI_MMS;i++) {
+		info->Entries[i].File.Buffer = NULL;
+	}
 	info->DateTimeAvailable = FALSE;
 
 	return ERR_NONE;
@@ -642,8 +710,9 @@ GSM_Error GSM_DecodeMMSFileToMultiPart(GSM_Debug_Info *di, GSM_File *file, GSM_E
 			pos++;
 			break;
 		case 0x0E:
-			smfprintf(di, "  Message size      : not done yet\n");
-			return ERR_FILENOTSUPPORTED;
+			smfprintf(di, "  Message size      : ignored for now\n");
+			pos += 2;
+			break;
 		case 0x0F:
 			smfprintf(di, "  Priority          : ");
 			switch (file->Buffer[pos++]) {
@@ -897,7 +966,7 @@ GSM_Error GSM_DecodeMMSFileToMultiPart(GSM_Debug_Info *di, GSM_File *file, GSM_E
 		pos+=i;
 
 		/* data */
-		info->Entries[info->EntriesNum].File.Buffer = realloc(info->Entries[info->EntriesNum].File.Buffer,len3);
+		info->Entries[info->EntriesNum].File.Buffer = (unsigned char *)realloc(info->Entries[info->EntriesNum].File.Buffer,len3);
 		info->Entries[info->EntriesNum].File.Used   = len3;
 		memcpy(info->Entries[info->EntriesNum].File.Buffer,file->Buffer+pos,len3);
 
