@@ -706,11 +706,16 @@ GSM_Error GSM_EncodeMultiPartSMS(GSM_Debug_Info *di,
 	case SMS_ConcatenatedTextLong:
 	case SMS_ConcatenatedTextLong16bit:
 		Class = Info->Class;
-		memcpy(Buffer,Info->Entries[0].Buffer,UnicodeLength(Info->Entries[0].Buffer)*2+2);
+		if (Info->Entries[0].Buffer == NULL) {
+			Buffer[0] = 0;
+			Buffer[1] = 0;
+		} else {
+			memcpy(Buffer,Info->Entries[0].Buffer,UnicodeLength(Info->Entries[0].Buffer)*2+2);
+		}
 		UDH = UDH_NoUDH;
 		if (Info->UnicodeCoding) {
 			Coding = SMS_Coding_Unicode_No_Compression;
-			Length = UnicodeLength(Info->Entries[0].Buffer);
+			Length = UnicodeLength(Buffer);
 			if (Info->Entries[0].ID == SMS_ConcatenatedTextLong16bit ||
 			    Info->Entries[0].ID == SMS_ConcatenatedAutoTextLong16bit) {
 				if (Length>70) UDH=UDH_ConcatenatedMessages16bit;
@@ -719,7 +724,7 @@ GSM_Error GSM_EncodeMultiPartSMS(GSM_Debug_Info *di,
 			}
 		} else {
 			Coding = SMS_Coding_Default_No_Compression;
-			FindDefaultAlphabetLen(Info->Entries[0].Buffer,&Length,&smslen,5000);
+			FindDefaultAlphabetLen(Buffer,&Length,&smslen,5000);
 			if (Info->Entries[0].ID == SMS_ConcatenatedTextLong16bit ||
 			    Info->Entries[0].ID == SMS_ConcatenatedAutoTextLong16bit) {
 				if (smslen>GSM_MAX_SMS_CHARS_LENGTH) UDH=UDH_ConcatenatedMessages16bit;
@@ -809,9 +814,12 @@ gboolean GSM_DecodeMMSIndication(GSM_Debug_Info *di,
 
 	/* Concatenate data */
 	for (i = 0; i < SMS->Number; i++) {
-		if (SMS->SMS[i].UDH.Type != UDH_MMSIndicatorLong ||
-		    SMS->SMS[i].UDH.Text[11] != i+1		 ||
-		    SMS->SMS[i].UDH.Text[10] != SMS->Number) {
+		if (SMS->SMS[i].UDH.Type == UDH_MMSIndicatorLong) {
+			if (SMS->SMS[i].UDH.Text[11] != i+1		 ||
+			    SMS->SMS[i].UDH.Text[10] != SMS->Number) {
+				return FALSE;
+			}
+		} else if (SMS->SMS[i].UDH.Type != UDH_UserUDH) {
 			return FALSE;
 		}
 		memcpy(Buffer + Length, SMS->SMS[i].Text, SMS->SMS[i].Length);
@@ -835,6 +843,7 @@ gboolean GSM_DecodeMMSIndication(GSM_Debug_Info *di,
 	/* First byte is transaction ID */
 	/* PUSH */
 	if (Buffer[1] != 0x06) {
+		dbgprintf(di, "Unsupported transaction id: 0x%02x\n", Buffer[1]);
 		return FALSE;
 	}
 	/* Process payload */
@@ -865,7 +874,12 @@ gboolean GSM_DecodeMMSIndication(GSM_Debug_Info *di,
 				i++;
 				if (Buffer[i] == 0) continue;
 				if (Buffer[i + 1] == 0x80) {
-					strcpy(Info->Entries[0].MMSIndicator->Sender, Buffer + i + 2);
+					if (Buffer[i + 2] < 32) {
+						/* String with length + encoding, we just ignore it for now */
+						strcpy(Info->Entries[0].MMSIndicator->Sender, Buffer + i + 4);
+					} else {
+						strcpy(Info->Entries[0].MMSIndicator->Sender, Buffer + i + 2);
+					}
 				}
 				i += Buffer[i];
 				break;
