@@ -30,7 +30,7 @@ GAMMU_SRC_DIR='@Gammu_SOURCE_DIR@'
 if SQLITE_BIN == '' or SQLITE_BIN[0] == '@':
     raise Exception('Please configure this script!')
 
-import gammu
+import gammu.smsd
 import sys
 import os
 import threading
@@ -71,7 +71,7 @@ if __name__ == '__main__':
         CreateSQLiteDB()
 
         # Load configuration
-        smsd = gammu.SMSD(smsdrc)
+        smsd = gammu.smsd.SMSD(smsdrc)
 
         # Inject SMS messages
         # Please note that SMSD is not thread safe, so you can not use inject and main loop from different threads
@@ -83,12 +83,21 @@ if __name__ == '__main__':
         # Start SMSD thread
         smsd_thread = threading.Thread(target = smsd.MainLoop)
         smsd_thread.start()
-
-        time.sleep(30)
+        # We need to let it run for some time here to finish initialization
+        time.sleep(10)
 
         # Show SMSD status
-        status = smsd.GetStatus()
-        print status
+        retries = 0
+        while retries < 60:
+            status = smsd.GetStatus()
+            for k in status.keys():
+                print '%s: %s' % (k, status[k])
+            print
+            if status['Sent'] >= 2:
+                break
+            time.sleep(10)
+            retries += 1
+
         if status['Sent'] != 2:
             raise Exception('Messages were not sent!')
 
