@@ -677,6 +677,7 @@ GSM_Error SMSD_ReadConfig(const char *filename, GSM_SMSDConfig *Config, gboolean
 	Config->resetfrequency = INI_GetInt(Config->smsdcfgfile, "smsd", "resetfrequency", 0);
 	Config->multiparttimeout = INI_GetInt(Config->smsdcfgfile, "smsd", "multiparttimeout", 600);
 	Config->maxretries = INI_GetInt(Config->smsdcfgfile, "smsd", "maxretries", 1);
+	Config->backend_retries = INI_GetInt(Config->smsdcfgfile, "smsd", "backendretries", 10);
 
 	SMSD_Log(DEBUG_NOTICE, Config, "commtimeout=%i, sendtimeout=%i, receivefrequency=%i, resetfrequency=%i",
 			Config->commtimeout, Config->sendtimeout, Config->receivefrequency, Config->resetfrequency);
@@ -1206,6 +1207,63 @@ GSM_Error SMSD_ProcessSMS(GSM_SMSDConfig *Config, GSM_SMSDService *Service, GSM_
 	return error;
 }
 
+/**
+ * Checks whether to process current (possibly) multipart message.
+ */
+gboolean SMSD_CheckMultipart(GSM_SMSDConfig *Config, GSM_SMSDService *Service, GSM_MultiSMSMessage *MultiSMS)
+{
+	gboolean same_id;
+	/* Does the message have UDH (is multipart)? */
+	if (MultiSMS->SMS[0].UDH.Type != UDH_NoUDH) {
+		return TRUE;
+	}
+
+	/* Do we have same id as last incomplete? */
+	same_id = (Config->IncompleteMessageID == MultiSMS->SMS[0].UDH.ID16bit || Config->IncompleteMessageID == MultiSMS->SMS[0].UDH.ID8bit);
+
+	/* Check if we have all parts */
+	if (MultiSMS->SMS[0].UDH.AllParts != MultiSMS->Number) {
+		goto success;
+	}
+
+
+	/* Have we seen this message recently? */
+	if (same_id) {
+		if (Config->IncompleteMessageTime != 0 && difftime(time(NULL), Config->IncompleteMessageTime) > Config->multiparttimeout) {
+			SMSD_Log(DEBUG_INFO, Config, "Incomplete multipart message 0x%02X, processing after timeout",
+				Config->IncompleteMessageID);
+		} else {
+			SMSD_Log(DEBUG_INFO, Config, "Incomplete multipart message 0x%02X, waiting for other parts (waited %.0f seconds)",
+				Config->IncompleteMessageID,
+				difftime(time(NULL), Config->IncompleteMessageTime));
+			return FALSE;
+		}
+	} else {
+		if (Config->IncompleteMessageTime == 0) {
+			if (MultiSMS->SMS[0].UDH.ID16bit != -1) {
+				 Config->IncompleteMessageID = MultiSMS->SMS[0].UDH.ID16bit;
+			} else {
+				 Config->IncompleteMessageID = MultiSMS->SMS[0].UDH.ID8bit;
+			}
+			Config->IncompleteMessageTime = time(NULL);
+			SMSD_Log(DEBUG_INFO, Config, "Incomplete multipart message 0x%02X, waiting for other parts",
+				Config->IncompleteMessageID);
+			return FALSE;
+		} else {
+			SMSD_Log(DEBUG_INFO, Config, "Incomplete multipart message 0x%02X, but waiting for other one",
+				Config->IncompleteMessageID);
+			return FALSE;
+		}
+	}
+
+success:
+	/* Clean multipart wait flag */
+	if (same_id) {
+		Config->IncompleteMessageTime = 0;
+	}
+	return TRUE;
+}
+
 /**
  * Reads message from phone, processes it and delete it from phone afterwards.
  *
@@ -1249,8 +1307,8 @@ gboolean SMSD_ReadDeleteSMS(GSM_SMSDConfig *Config, GSM_SMSDService *Service)
 					}
 
 					*(GetSMSData[GetSMSNumber]) = sms;
-					GetSMSData[GetSMSNumber + 1] = NULL;
 					GetSMSNumber++;
+					GetSMSData[GetSMSNumber] = NULL;
 				}
 				break;
 			default:
@@ -1260,6 +1318,9 @@ gboolean SMSD_ReadDeleteSMS(GSM_SMSDConfig *Config, GSM_SMSDService *Service)
 		start = FALSE;
 	}
 
+	/* Log how many messages were read */
+	SMSD_Log(DEBUG_INFO, Config, "Read %d messages", GetSMSNumber);
+
 	/* No messages to process */
 	if (GetSMSNumber == 0) {
 		return TRUE;
@@ -1272,43 +1333,17 @@ gboolean SMSD_ReadDeleteSMS(GSM_SMSDConfig *Config, GSM_SMSDService *Service)
 	error = GSM_LinkSMS(GSM_GetDebug(Config->gsm), GetSMSData, SortedSMS, TRUE);
 
 	/* Free memory */
-	i=0;
-	while (GetSMSData[i] != NULL) {
+	for (i = 0; GetSMSData[i] != NULL; i++) {
 		free(GetSMSData[i]);
 		GetSMSData[i] = NULL;
-		i++;
 	}
 	free(GetSMSData);
 
 	/* Process messages */
-	i=0;
-
 	for (i = 0; SortedSMS[i] != NULL; i++) {
-		/* Check if we have all parts */
-		if (SortedSMS[i]->SMS[0].UDH.Type != UDH_NoUDH) {
-			if (SortedSMS[i]->SMS[0].UDH.AllParts != SortedSMS[i]->Number) {
-				if (Config->IncompleteMessageTime != 0 && (Config->IncompleteMessageID == SortedSMS[i]->SMS[0].UDH.ID16bit || Config->IncompleteMessageID == SortedSMS[i]->SMS[0].UDH.ID8bit) && difftime(time(NULL), Config->IncompleteMessageTime) > Config->multiparttimeout) {
-					SMSD_Log(DEBUG_INFO, Config, "Incomplete multipart message 0x%02X, processing after timeout",
-						Config->IncompleteMessageID);
-				} else {
-					if (Config->IncompleteMessageTime == 0) {
-						if (SortedSMS[i]->SMS[0].UDH.ID16bit != -1) {
-							 Config->IncompleteMessageID = SortedSMS[i]->SMS[0].UDH.ID16bit;
-						} else {
-							 Config->IncompleteMessageID = SortedSMS[i]->SMS[0].UDH.ID8bit;
-						}
-						Config->IncompleteMessageTime = time(NULL);
-					}
-					SMSD_Log(DEBUG_INFO, Config, "Incomplete multipart message 0x%02X, waiting for other parts (waited %.0f seconds)",
-						Config->IncompleteMessageID, difftime(time(NULL), Config->IncompleteMessageTime));
-					goto cleanup;
-				}
-			}
-		}
-
-		/* Clean multipart wait flag */
-		if (Config->IncompleteMessageID == SortedSMS[i]->SMS[0].UDH.ID16bit || Config->IncompleteMessageID == SortedSMS[i]->SMS[0].UDH.ID8bit) {
-			Config->IncompleteMessageTime = 0;
+		/* Check multipart message parts */
+		if (!SMSD_CheckMultipart(Config, Service, SortedSMS[i])) {
+			goto cleanup;
 		}
 
 		/* Actually process the message */
@@ -1457,7 +1492,7 @@ GSM_Error SMSD_SendSMS(GSM_SMSDConfig *Config, GSM_SMSDService *Service)
 		Config->retries = 0;
 		strcpy(Config->prevSMSID, Config->SMSID);
 	}
-	for (i=0;i<sms.Number;i++) {
+	for (i = 0; i < sms.Number; i++) {
 		if (sms.SMS[i].SMSC.Location == 1) {
 			if (Config->SMSC.Location == 0) {
 				Config->SMSC.Location = 1;
@@ -1497,17 +1532,23 @@ GSM_Error SMSD_SendSMS(GSM_SMSDConfig *Config, GSM_SMSDService *Service)
 			Service->RefreshSendStatus(Config, Config->SMSID);
 			/* Update timestamp for phone in backend */
 			Service->RefreshPhoneStatus(Config);
-			GSM_GetCurrentDateTime (&Date);
-			z=Date.Second;
-			while (z==Date.Second) {
+			GSM_GetCurrentDateTime(&Date);
+			z = Date.Second;
+			while (z == Date.Second) {
 				usleep(10000);
 				GSM_GetCurrentDateTime(&Date);
-				GSM_ReadDevice(Config->gsm,TRUE);
-				if (Config->SendingSMSStatus != ERR_TIMEOUT) break;
+				GSM_ReadDevice(Config->gsm, TRUE);
+				if (Config->SendingSMSStatus != ERR_TIMEOUT) {
+					break;
+				}
+			}
+			if (Config->SendingSMSStatus != ERR_TIMEOUT) {
+				break;
 			}
-			if (Config->SendingSMSStatus != ERR_TIMEOUT) break;
 			j++;
-			if (j>Config->sendtimeout) break;
+			if (j > Config->sendtimeout) {
+				break;
+			}
 		}
 		if (Config->SendingSMSStatus != ERR_NONE) {
 			SMSD_LogError(DEBUG_INFO, Config, "Error getting send status of message", Config->SendingSMSStatus);
@@ -1515,12 +1556,14 @@ GSM_Error SMSD_SendSMS(GSM_SMSDConfig *Config, GSM_SMSDService *Service)
 		}
 		Config->Status->Sent++;
 		error = Service->AddSentSMSInfo(&sms, Config, Config->SMSID, i+1, SMSD_SEND_OK, Config->TPMR);
-		if (error!=ERR_NONE) {
+		if (error != ERR_NONE) {
 			goto failure_sent;
 		}
 	}
 	strcpy(Config->prevSMSID, "");
-	if (Service->MoveSMS(&sms,Config, Config->SMSID, FALSE, TRUE) != ERR_NONE) {
+	error = Service->MoveSMS(&sms,Config, Config->SMSID, FALSE, TRUE);
+	if (error != ERR_NONE) {
+		SMSD_LogError(DEBUG_ERROR, Config, "Error moving message", error);
 		Service->MoveSMS(&sms,Config, Config->SMSID, TRUE, FALSE);
 	}
 	return ERR_NONE;
@@ -1790,8 +1833,8 @@ GSM_Error SMSD_MainLoop(GSM_SMSDConfig *Config, gboolean exit_on_failure, int ma
 		if ((Config->statusfrequency > 0) && (difftime(time(NULL), laststatus) >= Config->statusfrequency)) {
 			SMSD_PhoneStatus(Config);
 			laststatus = time(NULL);
+			Service->RefreshPhoneStatus(Config);
 		}
-		Service->RefreshPhoneStatus(Config);
 
 		/* Sleep some time before another loop */
 		sleep(Config->loopsleep);
