@@ -8,6 +8,7 @@
 #include <assert.h>
 #include <stdlib.h>
 #include <signal.h>
+#include <string.h>
 #ifndef WIN32
 #include <unistd.h>
 #endif
@@ -40,6 +41,7 @@ NORETURN void version(void)
 	printf("  - %s\n", "GETOPT_LONG");
 #endif
 	printf("Backend services:\n");
+	printf("  - %s\n", "NULL");
 	printf("  - %s\n", "FILES");
 #ifdef HAVE_MYSQL_MYSQL_H
 	printf("  - %s\n", "MYSQL");
@@ -51,13 +53,13 @@ NORETURN void version(void)
 	printf("  - %s\n", "DBI");
 #endif
 	printf("\n");
-	printf("Copyright (C) 2003 - 2009 Michal Cihar <michal@cihar.com> and other authors.\n");
+	printf("Copyright (C) 2003 - 2010 Michal Cihar <michal@cihar.com> and other authors.\n");
 	printf("\n");
 	printf("License GPLv2: GNU GPL version 2 <http://creativecommons.org/licenses/GPL/2.0/>.\n");
 	printf("This is free software: you are free to change and redistribute it.\n");
 	printf("There is NO WARRANTY, to the extent permitted by law.\n");
 	printf("\n");
-	printf("Check <http://cihar.com/gammu/> for updates.\n");
+	printf("Check <http://wammu.eu/gammu/> for updates.\n");
 	printf("\n");
 	exit(0);
 }
@@ -143,7 +145,8 @@ int process_commandline(int argc, char **argv, SMSD_Parameters * params)
 				break;
 		}
 #if !defined(HAVE_GETOPT) && !defined(HAVE_GETOPT_LONG)
-		if (optind != -1) break;
+		if (optind != -1)
+			break;
 #endif
 	}
 
@@ -162,7 +165,7 @@ int main(int argc, char **argv)
 	GSM_Message_Type type = SMS_SMSD;
 	GSM_SMSDConfig *config;
 	const char program_name[] = "gammu-smsd-inject";
-	char newid[200];
+	char newid[200] = { 0 };
 
 	SMSD_Parameters params = {
 		NULL,
@@ -176,9 +179,16 @@ int main(int argc, char **argv)
 		FALSE,
 		FALSE,
 		FALSE,
-		FALSE
+		FALSE,
+		0
 	};
 
+	/*
+	 * We don't need gettext, but need to set locales so that
+	 * charset conversion works.
+	 */
+	GSM_InitLocales(NULL);
+
 	startarg = process_commandline(argc, argv, &params);
 
 	if (params.config_file == NULL) {
@@ -193,7 +203,8 @@ int main(int argc, char **argv)
 
 	error = CreateMessage(&type, &sms, argc, startarg, argv, NULL);
 	if (error != ERR_NONE) {
-		printf("Failed to create message: %s\n", GSM_ErrorString(error));
+		printf("Failed to create message: %s\n",
+		       GSM_ErrorString(error));
 		return 1;
 	}
 
@@ -209,11 +220,16 @@ int main(int argc, char **argv)
 
 	error = SMSD_InjectSMS(config, &sms, newid);
 	if (error != ERR_NONE) {
-		printf("Failed to inject message: %s\n", GSM_ErrorString(error));
+		printf("Failed to inject message: %s\n",
+		       GSM_ErrorString(error));
 		SMSD_FreeConfig(config);
 		return 3;
 	}
-	printf("Written message with ID %s\n", newid);
+	if (strlen(newid) == 0) {
+		printf("Written message without ID\n");
+	} else {
+		printf("Written message with ID %s\n", newid);
+	}
 
 	SMSD_FreeConfig(config);
 
