@@ -48,6 +48,7 @@ NORETURN void version(void)
 	printf("  - %s\n", "GETOPT_LONG");
 #endif
 	printf("Backend services:\n");
+	printf("  - %s\n", "NULL");
 	printf("  - %s\n", "FILES");
 #ifdef HAVE_MYSQL_MYSQL_H
 	printf("  - %s\n", "MYSQL");
@@ -59,13 +60,13 @@ NORETURN void version(void)
 	printf("  - %s\n", "DBI");
 #endif
 	printf("\n");
-	printf("Copyright (C) 2003 - 2009 Michal Cihar <michal@cihar.com> and other authors.\n");
+	printf("Copyright (C) 2003 - 2010 Michal Cihar <michal@cihar.com> and other authors.\n");
 	printf("\n");
 	printf("License GPLv2: GNU GPL version 2 <http://creativecommons.org/licenses/GPL/2.0/>.\n");
 	printf("This is free software: you are free to change and redistribute it.\n");
 	printf("There is NO WARRANTY, to the extent permitted by law.\n");
 	printf("\n");
-	printf("Check <http://cihar.com/gammu/> for updates.\n");
+	printf("Check <http://wammu.eu/gammu/> for updates.\n");
 	printf("\n");
 	exit(0);
 }
@@ -194,10 +195,17 @@ int main(int argc, char **argv)
 		FALSE,
 		FALSE,
 		FALSE,
-		FALSE
+		FALSE,
+		0
 	};
 
 
+	/*
+	 * We don't need gettext, but need to set locales so that
+	 * charset conversion works.
+	 */
+	GSM_InitLocales(NULL);
+
 	process_commandline(argc, argv, &params);
 
 	if (params.config_file == NULL) {
