@@ -307,13 +307,13 @@ static GSM_Error SMSDDBI_Query(GSM_SMSDConfig * Config, const char *query, dbi_r
 
 	*res = NULL;
 
-	for (attempts = 1; attempts < SMSD_SQL_RETRIES; attempts++) {
+	for (attempts = 1; attempts < Config->backend_retries; attempts++) {
 		SMSD_Log(DEBUG_SQL, Config, "Execute SQL: %s", query);
 		*res = dbi_conn_query(Config->DBConnDBI, query);
 		if (*res != NULL) return ERR_NONE;
 
 		SMSD_Log(DEBUG_INFO, Config, "SQL failed: %s", query);
-		if (attempts >= SMSD_SQL_RETRIES) {
+		if (attempts >= Config->backend_retries) {
 			return ERR_TIMEOUT;
 		}
 		/* Black magic to decide whether we should bail out or attempt to retry */
@@ -359,7 +359,7 @@ static GSM_Error SMSDDBI_Query(GSM_SMSDConfig * Config, const char *query, dbi_r
 				break;
 			}
 			attempts++;
-			if (attempts >= SMSD_SQL_RETRIES) {
+			if (attempts >= Config->backend_retries) {
 				return ERR_TIMEOUT;
 			}
 		}
@@ -533,15 +533,19 @@ static GSM_Error SMSDDBI_SaveInboxSMS(GSM_MultiSMSMessage *sms,
 			}
 
 			if (found) {
-				strcpy(buffer, "UPDATE sentitems SET DeliveryDateTime = '");
-				timestamp = Fill_Time_T(sms->SMS[i].SMSCTime);
-				if (strcmp(dbi_driver_get_name(dbi_conn_get_driver(Config->DBConnDBI)), "pgsql") == 0) {
-					timestruct = gmtime(&timestamp);
-					strftime(buffer + strlen(buffer), sizeof(buffer) - strlen(buffer), "%Y-%m-%d %H:%M:%S GMT", timestruct);
-				} else {
-					sprintf(buffer + strlen(buffer), "%ld", (long)timestamp);
+				strcpy(buffer, "UPDATE sentitems SET ");
+				if (!strcmp(smstext, "Delivered")) {
+					strcat(buffer, "DeliveryDateTime = '");
+					timestamp = Fill_Time_T(sms->SMS[i].SMSCTime);
+					if (strcmp(dbi_driver_get_name(dbi_conn_get_driver(Config->DBConnDBI)), "pgsql") == 0) {
+						timestruct = gmtime(&timestamp);
+						strftime(buffer + strlen(buffer), sizeof(buffer) - strlen(buffer), "%Y-%m-%d %H:%M:%S GMT", timestruct);
+					} else {
+						sprintf(buffer + strlen(buffer), "%ld", (long)timestamp);
+					}
+					strcat(buffer, "', ");
 				}
-				strcat(buffer, "', Status = '");
+				strcat(buffer, "Status = '");
 
 				if (!strcmp(smstext, "Delivered")) {
 					strcat(buffer, "DeliveryOK");
