@@ -73,7 +73,10 @@ static GSM_Error SMSDFiles_SaveInboxSMS(GSM_MultiSMSMessage *sms, GSM_SMSDConfig
 
 		if ((sms->SMS[i].PDU == SMS_Status_Report) && strcasecmp(Config->deliveryreport, "log") == 0) {
 			strcpy(buffer, DecodeUnicodeString(sms->SMS[i].Number));
-			SMSD_Log(DEBUG_NOTICE, Config, "Delivery report: %s to %s", DecodeUnicodeString(sms->SMS[i].Text), buffer);
+			SMSD_Log(DEBUG_NOTICE, Config, "Delivery report: %s to %s, message reference 0x%02x",
+				DecodeUnicodeString(sms->SMS[i].Text),
+				buffer,
+				sms->SMS[i].MessageReference);
 		} else {
 			if (locations_pos + strlen(FileName) + 2 >= locations_size) {
 				locations_size += strlen(FileName) + 30;
@@ -469,17 +472,22 @@ static GSM_Error SMSDFiles_MoveSMS(GSM_MultiSMSMessage *sms UNUSED,
 /* Adds SMS to Outbox */
 static GSM_Error SMSDFiles_CreateOutboxSMS(GSM_MultiSMSMessage *sms, GSM_SMSDConfig *Config, char *NewID)
 {
-	GSM_Error	error = ERR_NONE;
 	int 		i,j;
 	unsigned char 	FileName[100], FullName[400], ext[17], buffer[64],buffer2[400];
 	FILE 		*file;
+	time_t rawtime;
+	struct tm* timeinfo;
+
 #ifdef GSM_ENABLE_BACKUP
+	GSM_Error	error;
 	GSM_SMS_Backup 	backup;
 #endif
 
 	j = 0;
+	time(&rawtime);
+	timeinfo = localtime(&rawtime);
 
-	for (i=0;i<sms->Number;i++) {
+	for (i = 0; i < sms->Number; i++) {
 		if (strcasecmp(Config->outboxformat, "detail") == 0) {
 			strcpy(ext, "smsbackup");
 		} else {
@@ -489,12 +497,6 @@ static GSM_Error SMSDFiles_CreateOutboxSMS(GSM_MultiSMSMessage *sms, GSM_SMSDCon
 
 		file = NULL;
 		do {
-			time_t rawtime;
-			struct tm* timeinfo;
-
-			time(&rawtime);
-			timeinfo = localtime(&rawtime);
-
 			sprintf(FileName,
 				"OUTC%04d%02d%02d_%02d%02d%02d_00_%s_sms%d.%s",
 				1900 + timeinfo->tm_year,
@@ -508,7 +510,7 @@ static GSM_Error SMSDFiles_CreateOutboxSMS(GSM_MultiSMSMessage *sms, GSM_SMSDCon
 			strcat(FullName, FileName);
 			if (file) fclose(file);
 			file = fopen(FullName, "r");
-		} while ((i == 0) && file != NULL && (++j < 100));
+		} while (file != NULL && (++j < 100));
 
 		if (file) {
 			fclose(file);
@@ -528,7 +530,13 @@ static GSM_Error SMSDFiles_CreateOutboxSMS(GSM_MultiSMSMessage *sms, GSM_SMSDCon
 			}
 			backup.SMS[sms->Number] = NULL;
 			error = GSM_AddSMSBackupFile(FullName, &backup);
+
+			if (error != ERR_NONE) {
+				return error;
+			}
 #endif
+			/* Force leaving the loop */
+			i = sms->Number;
 		} else {
 			file = fopen(FullName, "wb");
 			if (file == NULL) {
@@ -538,28 +546,24 @@ static GSM_Error SMSDFiles_CreateOutboxSMS(GSM_MultiSMSMessage *sms, GSM_SMSDCon
 			switch (sms->SMS[i].Coding) {
 				case SMS_Coding_Unicode_No_Compression:
 				case SMS_Coding_Default_No_Compression:
-					DecodeUnicode(sms->SMS[i].Text,buffer2);
 					if (strcasecmp(Config->outboxformat, "unicode") == 0) {
 						buffer[0] = 0xFE;
 						buffer[1] = 0xFF;
 						chk_fwrite(buffer,1,2,file);
-						chk_fwrite(sms->SMS[i].Text,1,strlen(buffer2)*2,file);
+						chk_fwrite(sms->SMS[i].Text, 1, UnicodeLength(sms->SMS[i].Text) * 2, file);
 					} else {
-						chk_fwrite(buffer2,1,strlen(buffer2),file);
+						DecodeUnicode(sms->SMS[i].Text, buffer2);
+						chk_fwrite(buffer2, 1, strlen(buffer2), file);
 					}
 					break;
 				case SMS_Coding_8bit:
-					chk_fwrite(sms->SMS[i].Text,1,(size_t)sms->SMS[i].Length,file);
+					chk_fwrite(sms->SMS[i].Text, 1, (size_t)sms->SMS[i].Length, file);
 				default:
 					break;
 			}
 			fclose(file);
 		}
 
-		if (error != ERR_NONE) {
-			return error;
-		}
-
 		SMSD_Log(DEBUG_INFO, Config, "Created outbox message %s", FileName);
 	}
 
@@ -574,14 +578,15 @@ fail:
 
 static GSM_Error SMSDFiles_AddSentSMSInfo(GSM_MultiSMSMessage *sms UNUSED,
 		GSM_SMSDConfig *Config, char *ID UNUSED,
-		int Part, GSM_SMSDSendingError err, int TPMR UNUSED)
+		int Part, GSM_SMSDSendingError err, int TPMR)
 {
 	if (err == SMSD_SEND_OK) {
-		SMSD_Log(DEBUG_INFO, Config, "Transmitted %s (%s: %i) to %s",
+		SMSD_Log(DEBUG_INFO, Config, "Transmitted %s (%s: %i) to %s, message reference 0x%02x",
 				Config->SMSID,
 				(Part == sms->Number ? "total" : "part"),
 				Part,
-				DecodeUnicodeString(sms->SMS[0].Number));
+				DecodeUnicodeString(sms->SMS[0].Number),
+				TPMR);
 	}
 
   	return ERR_NONE;
