@@ -28,9 +28,15 @@ static GSM_Error SMSDMySQL_Free(GSM_SMSDConfig *Config)
 	return ERR_NONE;
 }
 
-static void SMSDMySQL_LogError(GSM_SMSDConfig *Config)
+static int SMSDMySQL_LogError(GSM_SMSDConfig *Config)
 {
-	SMSD_Log(DEBUG_ERROR, Config, "Error code: %d, Error: %s", mysql_errno(&Config->DBConnMySQL), mysql_error(&Config->DBConnMySQL));
+	int mysql_err;
+
+	mysql_err = mysql_errno(&Config->DBConnMySQL);
+
+	SMSD_Log(DEBUG_ERROR, Config, "Error code: %d, Error: %s", mysql_err, mysql_error(&Config->DBConnMySQL));
+
+	return mysql_err;
 }
 
 
@@ -132,53 +138,76 @@ static GSM_Error SMSDMySQL_Init(GSM_SMSDConfig *Config)
 	return ERR_NONE;
 }
 
-static GSM_Error SMSDMySQL_Query_Real(GSM_SMSDConfig *Config, const char *query, gboolean retry)
+static GSM_Error SMSDMySQL_Check_Reconnect(GSM_SMSDConfig *Config, int retry)
 {
+	int mysql_err;
+	GSM_Error error;
+
+	mysql_err = SMSDMySQL_LogError(Config);
+
+	/* MySQL server has gone away / Lost connection to MySQL */
+	if (mysql_err == 2006 || mysql_err == 2013) {
+		while (retry > 0) {
+			SMSD_Log(DEBUG_INFO, Config, "Trying to reconnect to the database...");
+			SMSDMySQL_Free(Config);
+			sleep(30);
+			error = SMSDMySQL_Init(Config);
+			if (error == ERR_NONE) {
+				return ERR_NONE;
+			}
+			retry--;
+		}
+		return ERR_TIMEOUT;
+	}
+
+	/* No retries for unknown errors */
+	return ERR_UNKNOWN;
+}
+
+
+static GSM_Error SMSDMySQL_Query_Real(GSM_SMSDConfig *Config, const char *query, int retry)
+{
+	GSM_Error error;
+
 	SMSD_Log(DEBUG_SQL, Config, "Execute SQL: %s", query);
 
 	if (mysql_query(&Config->DBConnMySQL, query) != 0) {
 		SMSD_Log(DEBUG_INFO, Config, "SQL failed: %s", query);
-		SMSDMySQL_LogError(Config);
-		/* MySQL server has gone away */
-		if (retry && mysql_errno(&Config->DBConnMySQL) == 2006) {
-			SMSD_Log(DEBUG_INFO, Config, "Trying to reconnect to the Database...");
-			SMSDMySQL_Free(Config);
-			sleep(30);
-			SMSDMySQL_Init(Config);
-			SMSD_Log(DEBUG_INFO, Config, "Retrying query...");
-			return SMSDMySQL_Query_Real(Config, query, FALSE);
+		error = SMSDMySQL_Check_Reconnect(Config, retry);
+		if (error != ERR_NONE) {
+			return error;
 		}
-
+		SMSD_Log(DEBUG_INFO, Config, "Retrying query...");
+		return SMSDMySQL_Query_Real(Config, query, retry - 1);
 	}
 	return ERR_NONE;
 }
 
 static GSM_Error SMSDMySQL_Query(GSM_SMSDConfig *Config, const char *query)
 {
-	return SMSDMySQL_Query_Real(Config, query, TRUE);
+	return SMSDMySQL_Query_Real(Config, query, Config->backend_retries);
 }
 
-static GSM_Error SMSDMySQL_Store_Real(GSM_SMSDConfig *Config, const char *query, MYSQL_RES **result, gboolean retry)
+static GSM_Error SMSDMySQL_Store_Real(GSM_SMSDConfig *Config, const char *query, MYSQL_RES **result, int retry)
 {
 	GSM_Error error;
 
-	error = SMSDMySQL_Query_Real(Config, query, TRUE);
-	if (error != ERR_NONE) return error;
+	error = SMSDMySQL_Query_Real(Config, query, retry);
+
+	if (error != ERR_NONE) {
+		return error;
+	}
 
 	*result = mysql_store_result(&Config->DBConnMySQL);
 
 	if (*result == NULL) {
 		SMSD_Log(DEBUG_INFO, Config, "Store result failed: %s", query);
-		SMSDMySQL_LogError(Config);
-		/* MySQL server has gone away */
-		if (retry && mysql_errno(&Config->DBConnMySQL) == 2006) {
-			SMSD_Log(DEBUG_INFO, Config, "Trying to reconnect to the Database...");
-			SMSDMySQL_Free(Config);
-			sleep(30);
-			SMSDMySQL_Init(Config);
-			SMSD_Log(DEBUG_INFO, Config, "Retrying query...");
-			return SMSDMySQL_Store_Real(Config, query, result, FALSE);
+		error = SMSDMySQL_Check_Reconnect(Config, retry);
+		if (error != ERR_NONE) {
+			return error;
 		}
+		SMSD_Log(DEBUG_INFO, Config, "Retrying query...");
+		return SMSDMySQL_Store_Real(Config, query, result, retry - 1);
 	}
 
 	return ERR_NONE;
@@ -186,7 +215,7 @@ static GSM_Error SMSDMySQL_Store_Real(GSM_SMSDConfig *Config, const char *query,
 
 static GSM_Error SMSDMySQL_Store(GSM_SMSDConfig *Config, const char *query, MYSQL_RES **result)
 {
-	return SMSDMySQL_Store_Real(Config, query, result, TRUE);
+	return SMSDMySQL_Store_Real(Config, query, result, Config->backend_retries);
 }
 
 static GSM_Error SMSDMySQL_InitAfterConnect(GSM_SMSDConfig *Config)
@@ -265,9 +294,15 @@ static GSM_Error SMSDMySQL_SaveInboxSMS(GSM_MultiSMSMessage *sms, GSM_SMSDConfig
 				}
 			}
 			if (found) {
-				sprintf(buffer,"UPDATE `sentitems` SET `DeliveryDateTime`='%04i-%02i-%02i %02i:%02i:%02i', `Status`='",
-					sms->SMS[i].SMSCTime.Year,sms->SMS[i].SMSCTime.Month,sms->SMS[i].SMSCTime.Day,
-					sms->SMS[i].SMSCTime.Hour,sms->SMS[i].SMSCTime.Minute,sms->SMS[i].SMSCTime.Second);
+				sprintf(buffer,"UPDATE `sentitems` SET ");
+				if (!strcmp(buffer3,"Delivered")) {
+					strcat(buffer, "`DeliveryDateTime` = '");
+					sprintf(buffer + strlen(buffer),"%04i-%02i-%02i %02i:%02i:%02i",
+						sms->SMS[i].SMSCTime.Year,sms->SMS[i].SMSCTime.Month,sms->SMS[i].SMSCTime.Day,
+						sms->SMS[i].SMSCTime.Hour,sms->SMS[i].SMSCTime.Minute,sms->SMS[i].SMSCTime.Second);
+					strcat(buffer, "', ");
+				}
+				strcat(buffer, "`Status` = '");
 				sprintf(buffer3,"%s",DecodeUnicodeString(sms->SMS[i].Text));
 				if (!strcmp(buffer3,"Delivered")) {
 					sprintf(buffer+strlen(buffer),"DeliveryOK");
@@ -281,7 +316,7 @@ static GSM_Error SMSDMySQL_SaveInboxSMS(GSM_MultiSMSMessage *sms, GSM_SMSDConfig
 				sprintf(buffer+strlen(buffer),"', `StatusError` = '%i'",sms->SMS[i].DeliveryStatus);
 				sprintf(buffer+strlen(buffer)," WHERE `ID` = '%s' AND `TPMR` = '%i'",Row[0],sms->SMS[i].MessageReference);
 				if (SMSDMySQL_Query(Config, buffer) != ERR_NONE) {
-					SMSD_Log(DEBUG_INFO, Config, "Error updating sent item i ndatabase (%s)", __FUNCTION__);
+					SMSD_Log(DEBUG_INFO, Config, "Error updating sent item into database (%s)", __FUNCTION__);
 					return ERR_UNKNOWN;
 				}
 			}
