@@ -7,7 +7,6 @@
 
 #include "../libgammu/gsmphones.h"
 
-
 int single_test(const char *string, GSM_Error expected)
 {
 	GSM_Feature features[GSM_MAX_PHONE_FEATURES + 1];
@@ -16,10 +15,7 @@ int single_test(const char *string, GSM_Error expected)
 	real = GSM_SetFeatureString(features, string);
 
 	if (real != expected) {
-		printf("Failed parsing of %s (got %s, expected %s)\n",
-				string,
-				GSM_FeatureToString(real),
-				GSM_FeatureToString(expected));
+		printf("Failed parsing of %s (got %s, expected %s)\n", string, GSM_FeatureToString(real), GSM_FeatureToString(expected));
 		return 1;
 	}
 	return 0;
@@ -37,7 +33,10 @@ int main(int argc, char **argv)
 	rc |= single_test("CAL33, CAL52,SQWE", ERR_NONE);
 	rc |= single_test("CAL33, FOO,SQWE", ERR_BADFEATURE);
 	rc |= single_test("CAL33, NO_ATOBEX ,SQWE", ERR_NONE);
-	rc |= single_test("CAL33, NO_ATOBEX ,SQWE, CAL33, NO_ATOBEX ,SQWE, CAL52,CAL33, NO_ATOBEX ,SQWE, CAL33, NO_ATOBEX ,SQWE, CAL52,CAL33, NO_ATOBEX ,SQWE, CAL33, NO_ATOBEX ,SQWE, CAL52", ERR_MOREMEMORY);
+	rc |=
+	    single_test
+	    ("CAL33, NO_ATOBEX ,SQWE, CAL33, NO_ATOBEX ,SQWE, CAL52,CAL33, NO_ATOBEX ,SQWE, CAL33, NO_ATOBEX ,SQWE, CAL52,CAL33, NO_ATOBEX ,SQWE, CAL33, NO_ATOBEX ,SQWE, CAL52",
+	     ERR_MOREMEMORY);
 
 	return rc;
 }
@@ -45,4 +44,3 @@ int main(int argc, char **argv)
 /* Editor configuration
  * vim: noexpandtab sw=8 ts=8 sts=8 tw=72:
  */
-
