@@ -25,14 +25,14 @@ int main(int argc, char **argv)
 	char vcard_buffer[65536];
 	FILE *f;
 	size_t len;
-	bool generate = false;
+	gboolean generate = FALSE;
 	GSM_Backup backup;
 	int i;
 	GSM_Debug_Info *debug_info;
 
 	/* Configure debugging */
 	debug_info = GSM_GetGlobalDebug();
-	GSM_SetDebugFileDescriptor(stderr, false, debug_info);
+	GSM_SetDebugFileDescriptor(stderr, FALSE, debug_info);
 	GSM_SetDebugLevel("textall", debug_info);
 
 	/* Check parameters */
@@ -43,7 +43,7 @@ int main(int argc, char **argv)
 
 	/* Check for generating option */
 	if (argc == 4 && strcmp(argv[3], "generate") == 0) {
-		generate = true;
+		generate = TRUE;
 	}
 
 	/* Open file */
@@ -66,7 +66,7 @@ int main(int argc, char **argv)
 
 	/* Encode vCard back */
 	pos = 0;
-	error = GSM_EncodeVCARD(NULL, vcard_buffer, sizeof(vcard_buffer), &pos, &pbk, true, SonyEricsson_VCard21);
+	error = GSM_EncodeVCARD(NULL, vcard_buffer, sizeof(vcard_buffer), &pos, &pbk, TRUE, SonyEricsson_VCard21);
 	gammu_test_result(error, "GSM_EncodeVCARD");
 
 	/*
@@ -82,7 +82,7 @@ int main(int argc, char **argv)
 		pbk.Location = 0;
 		backup.PhonePhonebook[0] = &pbk;
 		backup.PhonePhonebook[1] = NULL;
-		error = GSM_SaveBackupFile(argv[2], &backup, true);
+		error = GSM_SaveBackupFile(argv[2], &backup, TRUE);
 		gammu_test_result(error, "GSM_SaveBackupFile");
 	}
 
@@ -99,57 +99,53 @@ int main(int argc, char **argv)
 		test_result(pbk.Entries[i].EntryType == backup.PhonePhonebook[0]->Entries[i].EntryType);
 		printf("Entry type: %d\n", pbk.Entries[i].EntryType);
 		switch (pbk.Entries[i].EntryType) {
-			case PBK_Number_General     :
-			case PBK_Number_Mobile      :
-			case PBK_Number_Work        :
-			case PBK_Number_Fax         :
-			case PBK_Number_Home        :
-			case PBK_Number_Pager       :
-			case PBK_Number_Other       :
+			case PBK_Number_General:
+			case PBK_Number_Mobile:
+			case PBK_Number_Mobile_Work:
+			case PBK_Number_Mobile_Home:
+			case PBK_Number_Work:
+			case PBK_Number_Fax:
+			case PBK_Number_Home:
+			case PBK_Number_Pager:
+			case PBK_Number_Other:
 			case PBK_Number_Messaging:
-			case PBK_Text_Note          :
-			case PBK_Text_Postal        :
+			case PBK_Text_Note:
+			case PBK_Text_Postal:
 			case PBK_Text_WorkPostal:
-			case PBK_Text_Email         :
-			case PBK_Text_Email2        :
-			case PBK_Text_URL           :
-			case PBK_Text_LUID          :
-			case PBK_Text_Name          :
-			case PBK_Text_LastName      :
-			case PBK_Text_FirstName     :
-			case PBK_Text_FormalName    :
-			case PBK_Text_NickName      :
-			case PBK_Text_Company       :
-			case PBK_Text_JobTitle      :
-			case PBK_Text_StreetAddress :
-			case PBK_Text_City          :
-			case PBK_Text_State         :
-			case PBK_Text_Zip           :
-			case PBK_Text_Country       :
-			case PBK_Text_WorkStreetAddress :
-			case PBK_Text_WorkCity          :
-			case PBK_Text_WorkState         :
-			case PBK_Text_WorkZip           :
-			case PBK_Text_WorkCountry       :
-			case PBK_Text_Custom1       :
-			case PBK_Text_Custom2       :
-			case PBK_Text_Custom3       :
-			case PBK_Text_Custom4       :
+			case PBK_Text_Email:
+			case PBK_Text_Email2:
+			case PBK_Text_URL:
+			case PBK_Text_LUID:
+			case PBK_Text_Name:
+			case PBK_Text_LastName:
+			case PBK_Text_FirstName:
+			case PBK_Text_FormalName:
+			case PBK_Text_NickName:
+			case PBK_Text_Company:
+			case PBK_Text_JobTitle:
+			case PBK_Text_StreetAddress:
+			case PBK_Text_City:
+			case PBK_Text_State:
+			case PBK_Text_Zip:
+			case PBK_Text_Country:
+			case PBK_Text_WorkStreetAddress:
+			case PBK_Text_WorkCity:
+			case PBK_Text_WorkState:
+			case PBK_Text_WorkZip:
+			case PBK_Text_WorkCountry:
+			case PBK_Text_Custom1:
+			case PBK_Text_Custom2:
+			case PBK_Text_Custom3:
+			case PBK_Text_Custom4:
 			case PBK_Text_UserID:
 			case PBK_Text_PictureName:
 			case PBK_PushToTalkID:
-				test_result(mywstrncmp(
-					pbk.Entries[i].Text,
-					backup.PhonePhonebook[0]->Entries[i].Text,
-					0) == true);
+				test_result(mywstrncmp(pbk.Entries[i].Text, backup.PhonePhonebook[0]->Entries[i].Text, 0) == TRUE);
 				break;
-			case PBK_Photo       :
+			case PBK_Photo:
 				test_result((pbk.Entries[i].Picture.Length ==
-					backup.PhonePhonebook[0]->Entries[i].Picture.Length) &&
-					memcmp(
-					pbk.Entries[i].Picture.Buffer,
-					backup.PhonePhonebook[0]->Entries[i].Picture.Buffer,
-					pbk.Entries[i].Picture.Length) == 0);
+					     backup.PhonePhonebook[0]->Entries[i].Picture.Length) &&
+					    memcmp(pbk.Entries[i].Picture.Buffer, backup.PhonePhonebook[0]->Entries[i].Picture.Buffer, pbk.Entries[i].Picture.Length) == 0);
 				free(pbk.Entries[i].Picture.Buffer);
 				break;
 			case PBK_Date:
@@ -160,7 +156,7 @@ int main(int argc, char **argv)
 			case PBK_RingtoneID:
 			case PBK_PictureID:
 			case PBK_CallLength:
-			case PBK_Caller_Group       :
+			case PBK_Caller_Group:
 				test_result(pbk.Entries[i].Number == backup.PhonePhonebook[0]->Entries[i].Number);
 				break;
 		}
